'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    """
    pass

def create_application(Name=None, Description=None, Tags=None):
    """
    An application in AppConfig is a logical unit of code that provides capabilities for your customers. For example, an application can be a microservice that runs on Amazon EC2 instances, a mobile application installed by your users, a serverless application using Amazon API Gateway and AWS Lambda, or any system you run on behalf of others.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_application(
        Name='string',
        Description='string',
        Tags={
            'string': 'string'
        }
    )
    
    
    :type Name: string
    :param Name: [REQUIRED]\nA name for the application.\n

    :type Description: string
    :param Description: A description of the application.

    :type Tags: dict
    :param Tags: Metadata to assign to the application. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define.\n\n(string) --\n(string) --\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'Id': 'string',
    'Name': 'string',
    'Description': 'string'
}


Response Structure

(dict) --

Id (string) --
The application ID.

Name (string) --
The application name.

Description (string) --
The description of the application.







Exceptions

AppConfig.Client.exceptions.BadRequestException
AppConfig.Client.exceptions.InternalServerException


    :return: {
        'Id': 'string',
        'Name': 'string',
        'Description': 'string'
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.BadRequestException
    AppConfig.Client.exceptions.InternalServerException
    
    """
    pass

def create_configuration_profile(ApplicationId=None, Name=None, Description=None, LocationUri=None, RetrievalRoleArn=None, Validators=None, Tags=None):
    """
    Information that enables AppConfig to access the configuration source. Valid configuration sources include Systems Manager (SSM) documents, SSM Parameter Store parameters, and Amazon S3 objects. A configuration profile includes the following information.
    For more information, see Create a Configuration and a Configuration Profile in the AWS AppConfig User Guide .
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_configuration_profile(
        ApplicationId='string',
        Name='string',
        Description='string',
        LocationUri='string',
        RetrievalRoleArn='string',
        Validators=[
            {
                'Type': 'JSON_SCHEMA'|'LAMBDA',
                'Content': 'string'
            },
        ],
        Tags={
            'string': 'string'
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe application ID.\n

    :type Name: string
    :param Name: [REQUIRED]\nA name for the configuration profile.\n

    :type Description: string
    :param Description: A description of the configuration profile.

    :type LocationUri: string
    :param LocationUri: [REQUIRED]\nA URI to locate the configuration. You can specify a Systems Manager (SSM) document, an SSM Parameter Store parameter, or an Amazon S3 object. For an SSM document, specify either the document name in the format ssm-document://<Document_name> or the Amazon Resource Name (ARN). For a parameter, specify either the parameter name in the format ssm-parameter://<Parameter_name> or the ARN. For an Amazon S3 object, specify the URI in the following format: s3://<bucket>/<objectKey> . Here is an example: s3://my-bucket/my-app/us-east-1/my-config.json\n

    :type RetrievalRoleArn: string
    :param RetrievalRoleArn: [REQUIRED]\nThe ARN of an IAM role with permission to access the configuration at the specified LocationUri.\n

    :type Validators: list
    :param Validators: A list of methods for validating the configuration.\n\n(dict) --A validator provides a syntactic or semantic check to ensure the configuration you want to deploy functions as intended. To validate your application configuration data, you provide a schema or a Lambda function that runs against the configuration. The configuration deployment or update can only proceed when the configuration data is valid.\n\nType (string) -- [REQUIRED]AppConfig supports validators of type JSON_SCHEMA and LAMBDA\n\nContent (string) -- [REQUIRED]Either the JSON Schema content or the Amazon Resource Name (ARN) of an AWS Lambda function.\n\n\n\n\n

    :type Tags: dict
    :param Tags: Metadata to assign to the configuration profile. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define.\n\n(string) --\n(string) --\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ApplicationId': 'string',
    'Id': 'string',
    'Name': 'string',
    'Description': 'string',
    'LocationUri': 'string',
    'RetrievalRoleArn': 'string',
    'Validators': [
        {
            'Type': 'JSON_SCHEMA'|'LAMBDA',
            'Content': 'string'
        },
    ]
}


Response Structure

(dict) --

ApplicationId (string) --
The application ID.

Id (string) --
The configuration profile ID.

Name (string) --
The name of the configuration profile.

Description (string) --
The configuration profile description.

LocationUri (string) --
The URI location of the configuration.

RetrievalRoleArn (string) --
The ARN of an IAM role with permission to access the configuration at the specified LocationUri.

Validators (list) --
A list of methods for validating the configuration.

(dict) --
A validator provides a syntactic or semantic check to ensure the configuration you want to deploy functions as intended. To validate your application configuration data, you provide a schema or a Lambda function that runs against the configuration. The configuration deployment or update can only proceed when the configuration data is valid.

Type (string) --
AppConfig supports validators of type JSON_SCHEMA and LAMBDA

Content (string) --
Either the JSON Schema content or the Amazon Resource Name (ARN) of an AWS Lambda function.











Exceptions

AppConfig.Client.exceptions.BadRequestException
AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException


    :return: {
        'ApplicationId': 'string',
        'Id': 'string',
        'Name': 'string',
        'Description': 'string',
        'LocationUri': 'string',
        'RetrievalRoleArn': 'string',
        'Validators': [
            {
                'Type': 'JSON_SCHEMA'|'LAMBDA',
                'Content': 'string'
            },
        ]
    }
    
    
    :returns: 
    ApplicationId (string) -- [REQUIRED]
    The application ID.
    
    Name (string) -- [REQUIRED]
    A name for the configuration profile.
    
    Description (string) -- A description of the configuration profile.
    LocationUri (string) -- [REQUIRED]
    A URI to locate the configuration. You can specify a Systems Manager (SSM) document, an SSM Parameter Store parameter, or an Amazon S3 object. For an SSM document, specify either the document name in the format ssm-document://<Document_name> or the Amazon Resource Name (ARN). For a parameter, specify either the parameter name in the format ssm-parameter://<Parameter_name> or the ARN. For an Amazon S3 object, specify the URI in the following format: s3://<bucket>/<objectKey> . Here is an example: s3://my-bucket/my-app/us-east-1/my-config.json
    
    RetrievalRoleArn (string) -- [REQUIRED]
    The ARN of an IAM role with permission to access the configuration at the specified LocationUri.
    
    Validators (list) -- A list of methods for validating the configuration.
    
    (dict) --A validator provides a syntactic or semantic check to ensure the configuration you want to deploy functions as intended. To validate your application configuration data, you provide a schema or a Lambda function that runs against the configuration. The configuration deployment or update can only proceed when the configuration data is valid.
    
    Type (string) -- [REQUIRED]AppConfig supports validators of type JSON_SCHEMA and LAMBDA
    
    Content (string) -- [REQUIRED]Either the JSON Schema content or the Amazon Resource Name (ARN) of an AWS Lambda function.
    
    
    
    
    
    Tags (dict) -- Metadata to assign to the configuration profile. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define.
    
    (string) --
    (string) --
    
    
    
    
    
    """
    pass

def create_deployment_strategy(Name=None, Description=None, DeploymentDurationInMinutes=None, FinalBakeTimeInMinutes=None, GrowthFactor=None, GrowthType=None, ReplicateTo=None, Tags=None):
    """
    A deployment strategy defines important criteria for rolling out your configuration to the designated targets. A deployment strategy includes: the overall duration required, a percentage of targets to receive the deployment during each interval, an algorithm that defines how percentage grows, and bake time.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_deployment_strategy(
        Name='string',
        Description='string',
        DeploymentDurationInMinutes=123,
        FinalBakeTimeInMinutes=123,
        GrowthFactor=...,
        GrowthType='LINEAR'|'EXPONENTIAL',
        ReplicateTo='NONE'|'SSM_DOCUMENT',
        Tags={
            'string': 'string'
        }
    )
    
    
    :type Name: string
    :param Name: [REQUIRED]\nA name for the deployment strategy.\n

    :type Description: string
    :param Description: A description of the deployment strategy.

    :type DeploymentDurationInMinutes: integer
    :param DeploymentDurationInMinutes: [REQUIRED]\nTotal amount of time for a deployment to last.\n

    :type FinalBakeTimeInMinutes: integer
    :param FinalBakeTimeInMinutes: The amount of time AppConfig monitors for alarms before considering the deployment to be complete and no longer eligible for automatic roll back.

    :type GrowthFactor: float
    :param GrowthFactor: [REQUIRED]\nThe percentage of targets to receive a deployed configuration during each interval.\n

    :type GrowthType: string
    :param GrowthType: The algorithm used to define how percentage grows over time. AWS AppConfig supports the following growth types:\n\nLinear : For this type, AppConfig processes the deployment by dividing the total number of targets by the value specified for Step percentage . For example, a linear deployment that uses a Step percentage of 10 deploys the configuration to 10 percent of the hosts. After those deployments are complete, the system deploys the configuration to the next 10 percent. This continues until 100% of the targets have successfully received the configuration.Exponential : For this type, AppConfig processes the deployment exponentially using the following formula: G*(2^N) . In this formula, G is the growth factor specified by the user and N is the number of steps until the configuration is deployed to all targets. For example, if you specify a growth factor of 2, then the system rolls out the configuration as follows:\n2*(2^0)\n2*(2^1)\n2*(2^2)\n\nExpressed numerically, the deployment rolls out as follows: 2% of the targets, 4% of the targets, 8% of the targets, and continues until the configuration has been deployed to all targets.\n

    :type ReplicateTo: string
    :param ReplicateTo: [REQUIRED]\nSave the deployment strategy to a Systems Manager (SSM) document.\n

    :type Tags: dict
    :param Tags: Metadata to assign to the deployment strategy. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define.\n\n(string) --\n(string) --\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'Id': 'string',
    'Name': 'string',
    'Description': 'string',
    'DeploymentDurationInMinutes': 123,
    'GrowthType': 'LINEAR'|'EXPONENTIAL',
    'GrowthFactor': ...,
    'FinalBakeTimeInMinutes': 123,
    'ReplicateTo': 'NONE'|'SSM_DOCUMENT'
}


Response Structure

(dict) --

Id (string) --
The deployment strategy ID.

Name (string) --
The name of the deployment strategy.

Description (string) --
The description of the deployment strategy.

DeploymentDurationInMinutes (integer) --
Total amount of time the deployment lasted.

GrowthType (string) --
The algorithm used to define how percentage grew over time.

GrowthFactor (float) --
The percentage of targets that received a deployed configuration during each interval.

FinalBakeTimeInMinutes (integer) --
The amount of time AppConfig monitored for alarms before considering the deployment to be complete and no longer eligible for automatic roll back.

ReplicateTo (string) --
Save the deployment strategy to a Systems Manager (SSM) document.







Exceptions

AppConfig.Client.exceptions.InternalServerException
AppConfig.Client.exceptions.BadRequestException


    :return: {
        'Id': 'string',
        'Name': 'string',
        'Description': 'string',
        'DeploymentDurationInMinutes': 123,
        'GrowthType': 'LINEAR'|'EXPONENTIAL',
        'GrowthFactor': ...,
        'FinalBakeTimeInMinutes': 123,
        'ReplicateTo': 'NONE'|'SSM_DOCUMENT'
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.InternalServerException
    AppConfig.Client.exceptions.BadRequestException
    
    """
    pass

def create_environment(ApplicationId=None, Name=None, Description=None, Monitors=None, Tags=None):
    """
    For each application, you define one or more environments. An environment is a logical deployment group of AppConfig targets, such as applications in a Beta or Production environment. You can also define environments for application subcomponents such as the Web , Mobile and Back-end components for your application. You can configure Amazon CloudWatch alarms for each environment. The system monitors alarms during a configuration deployment. If an alarm is triggered, the system rolls back the configuration.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_environment(
        ApplicationId='string',
        Name='string',
        Description='string',
        Monitors=[
            {
                'AlarmArn': 'string',
                'AlarmRoleArn': 'string'
            },
        ],
        Tags={
            'string': 'string'
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe application ID.\n

    :type Name: string
    :param Name: [REQUIRED]\nA name for the environment.\n

    :type Description: string
    :param Description: A description of the environment.

    :type Monitors: list
    :param Monitors: Amazon CloudWatch alarms to monitor during the deployment process.\n\n(dict) --Amazon CloudWatch alarms to monitor during the deployment process.\n\nAlarmArn (string) --ARN of the Amazon CloudWatch alarm.\n\nAlarmRoleArn (string) --ARN of an IAM role for AppConfig to monitor AlarmArn .\n\n\n\n\n

    :type Tags: dict
    :param Tags: Metadata to assign to the environment. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define.\n\n(string) --\n(string) --\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ApplicationId': 'string',
    'Id': 'string',
    'Name': 'string',
    'Description': 'string',
    'State': 'READY_FOR_DEPLOYMENT'|'DEPLOYING'|'ROLLING_BACK'|'ROLLED_BACK',
    'Monitors': [
        {
            'AlarmArn': 'string',
            'AlarmRoleArn': 'string'
        },
    ]
}


Response Structure

(dict) --

ApplicationId (string) --
The application ID.

Id (string) --
The environment ID.

Name (string) --
The name of the environment.

Description (string) --
The description of the environment.

State (string) --
The state of the environment. An environment can be in one of the following states: READY_FOR_DEPLOYMENT , DEPLOYING , ROLLING_BACK , or ROLLED_BACK

Monitors (list) --
Amazon CloudWatch alarms monitored during the deployment.

(dict) --
Amazon CloudWatch alarms to monitor during the deployment process.

AlarmArn (string) --
ARN of the Amazon CloudWatch alarm.

AlarmRoleArn (string) --
ARN of an IAM role for AppConfig to monitor AlarmArn .











Exceptions

AppConfig.Client.exceptions.InternalServerException
AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.BadRequestException


    :return: {
        'ApplicationId': 'string',
        'Id': 'string',
        'Name': 'string',
        'Description': 'string',
        'State': 'READY_FOR_DEPLOYMENT'|'DEPLOYING'|'ROLLING_BACK'|'ROLLED_BACK',
        'Monitors': [
            {
                'AlarmArn': 'string',
                'AlarmRoleArn': 'string'
            },
        ]
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.InternalServerException
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.BadRequestException
    
    """
    pass

def delete_application(ApplicationId=None):
    """
    Delete an application. Deleting an application does not delete a configuration from a host.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_application(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe ID of the application to delete.\n

    """
    pass

def delete_configuration_profile(ApplicationId=None, ConfigurationProfileId=None):
    """
    Delete a configuration profile. Deleting a configuration profile does not delete a configuration from a host.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_configuration_profile(
        ApplicationId='string',
        ConfigurationProfileId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe application ID that includes the configuration profile you want to delete.\n

    :type ConfigurationProfileId: string
    :param ConfigurationProfileId: [REQUIRED]\nThe ID of the configuration profile you want to delete.\n

    :returns: 
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.ConflictException
    AppConfig.Client.exceptions.InternalServerException
    AppConfig.Client.exceptions.BadRequestException
    
    """
    pass

def delete_deployment_strategy(DeploymentStrategyId=None):
    """
    Delete a deployment strategy. Deleting a deployment strategy does not delete a configuration from a host.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_deployment_strategy(
        DeploymentStrategyId='string'
    )
    
    
    :type DeploymentStrategyId: string
    :param DeploymentStrategyId: [REQUIRED]\nThe ID of the deployment strategy you want to delete.\n

    """
    pass

def delete_environment(ApplicationId=None, EnvironmentId=None):
    """
    Delete an environment. Deleting an environment does not delete a configuration from a host.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_environment(
        ApplicationId='string',
        EnvironmentId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe application ID that includes the environment you want to delete.\n

    :type EnvironmentId: string
    :param EnvironmentId: [REQUIRED]\nThe ID of the environment you want to delete.\n

    :returns: 
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.ConflictException
    AppConfig.Client.exceptions.InternalServerException
    AppConfig.Client.exceptions.BadRequestException
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to\nClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid\nfor. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By\ndefault, the http method is whatever is used in the method\'s model.

    """
    pass

def get_application(ApplicationId=None):
    """
    Retrieve information about an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_application(
        ApplicationId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe ID of the application you want to get.\n

    :rtype: dict
ReturnsResponse Syntax{
    'Id': 'string',
    'Name': 'string',
    'Description': 'string'
}


Response Structure

(dict) --
Id (string) --The application ID.

Name (string) --The application name.

Description (string) --The description of the application.






Exceptions

AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException
AppConfig.Client.exceptions.BadRequestException


    :return: {
        'Id': 'string',
        'Name': 'string',
        'Description': 'string'
    }
    
    
    """
    pass

def get_configuration(Application=None, Environment=None, Configuration=None, ClientId=None, ClientConfigurationVersion=None):
    """
    Receive information about a configuration.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_configuration(
        Application='string',
        Environment='string',
        Configuration='string',
        ClientId='string',
        ClientConfigurationVersion='string'
    )
    
    
    :type Application: string
    :param Application: [REQUIRED]\nThe application to get. Specify either the application name or the application ID.\n

    :type Environment: string
    :param Environment: [REQUIRED]\nThe environment to get. Specify either the environment name or the environment ID.\n

    :type Configuration: string
    :param Configuration: [REQUIRED]\nThe configuration to get. Specify either the configuration name or the configuration ID.\n

    :type ClientId: string
    :param ClientId: [REQUIRED]\nA unique ID to identify the client for the configuration. This ID enables AppConfig to deploy the configuration in intervals, as defined in the deployment strategy.\n

    :type ClientConfigurationVersion: string
    :param ClientConfigurationVersion: The configuration version returned in the most recent GetConfiguration response.\n\nWarning\nAWS AppConfig uses the value of the ClientConfigurationVersion parameter to identify the configuration version on your clients. If you don\xe2\x80\x99t send ClientConfigurationVersion with each call to GetConfiguration , your clients receive the current configuration. You are charged each time your clients receive a configuration.\nTo avoid excess charges, we recommend that you include the ClientConfigurationVersion value with every call to GetConfiguration . This value must be saved on your client. Subsequent calls to GetConfiguration must pass this value by using the ClientConfigurationVersion parameter.\n\nFor more information about working with configurations, see Retrieving the Configuration in the AWS AppConfig User Guide .\n

    :rtype: dict

ReturnsResponse Syntax
{
    'Content': StreamingBody(),
    'ConfigurationVersion': 'string',
    'ContentType': 'string'
}


Response Structure

(dict) --

Content (StreamingBody) --
The content of the configuration or the configuration data.

ConfigurationVersion (string) --
The configuration version.

ContentType (string) --
A standard MIME type describing the format of the configuration content. For more information, see Content-Type .







Exceptions

AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException
AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.BadRequestException


    :return: {
        'Content': StreamingBody(),
        'ConfigurationVersion': 'string',
        'ContentType': 'string'
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.InternalServerException
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.BadRequestException
    
    """
    pass

def get_configuration_profile(ApplicationId=None, ConfigurationProfileId=None):
    """
    Retrieve information about a configuration profile.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_configuration_profile(
        ApplicationId='string',
        ConfigurationProfileId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe ID of the application that includes the configuration profile you want to get.\n

    :type ConfigurationProfileId: string
    :param ConfigurationProfileId: [REQUIRED]\nThe ID of the configuration profile you want to get.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ApplicationId': 'string',
    'Id': 'string',
    'Name': 'string',
    'Description': 'string',
    'LocationUri': 'string',
    'RetrievalRoleArn': 'string',
    'Validators': [
        {
            'Type': 'JSON_SCHEMA'|'LAMBDA',
            'Content': 'string'
        },
    ]
}


Response Structure

(dict) --

ApplicationId (string) --
The application ID.

Id (string) --
The configuration profile ID.

Name (string) --
The name of the configuration profile.

Description (string) --
The configuration profile description.

LocationUri (string) --
The URI location of the configuration.

RetrievalRoleArn (string) --
The ARN of an IAM role with permission to access the configuration at the specified LocationUri.

Validators (list) --
A list of methods for validating the configuration.

(dict) --
A validator provides a syntactic or semantic check to ensure the configuration you want to deploy functions as intended. To validate your application configuration data, you provide a schema or a Lambda function that runs against the configuration. The configuration deployment or update can only proceed when the configuration data is valid.

Type (string) --
AppConfig supports validators of type JSON_SCHEMA and LAMBDA

Content (string) --
Either the JSON Schema content or the Amazon Resource Name (ARN) of an AWS Lambda function.











Exceptions

AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException
AppConfig.Client.exceptions.BadRequestException


    :return: {
        'ApplicationId': 'string',
        'Id': 'string',
        'Name': 'string',
        'Description': 'string',
        'LocationUri': 'string',
        'RetrievalRoleArn': 'string',
        'Validators': [
            {
                'Type': 'JSON_SCHEMA'|'LAMBDA',
                'Content': 'string'
            },
        ]
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.InternalServerException
    AppConfig.Client.exceptions.BadRequestException
    
    """
    pass

def get_deployment(ApplicationId=None, EnvironmentId=None, DeploymentNumber=None):
    """
    Retrieve information about a configuration deployment.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_deployment(
        ApplicationId='string',
        EnvironmentId='string',
        DeploymentNumber=123
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe ID of the application that includes the deployment you want to get.\n

    :type EnvironmentId: string
    :param EnvironmentId: [REQUIRED]\nThe ID of the environment that includes the deployment you want to get.\n

    :type DeploymentNumber: integer
    :param DeploymentNumber: [REQUIRED]\nThe sequence number of the deployment.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ApplicationId': 'string',
    'EnvironmentId': 'string',
    'DeploymentStrategyId': 'string',
    'ConfigurationProfileId': 'string',
    'DeploymentNumber': 123,
    'ConfigurationName': 'string',
    'ConfigurationLocationUri': 'string',
    'ConfigurationVersion': 'string',
    'Description': 'string',
    'DeploymentDurationInMinutes': 123,
    'GrowthType': 'LINEAR'|'EXPONENTIAL',
    'GrowthFactor': ...,
    'FinalBakeTimeInMinutes': 123,
    'State': 'BAKING'|'VALIDATING'|'DEPLOYING'|'COMPLETE'|'ROLLING_BACK'|'ROLLED_BACK',
    'EventLog': [
        {
            'EventType': 'PERCENTAGE_UPDATED'|'ROLLBACK_STARTED'|'ROLLBACK_COMPLETED'|'BAKE_TIME_STARTED'|'DEPLOYMENT_STARTED'|'DEPLOYMENT_COMPLETED',
            'TriggeredBy': 'USER'|'APPCONFIG'|'CLOUDWATCH_ALARM'|'INTERNAL_ERROR',
            'Description': 'string',
            'OccurredAt': datetime(2015, 1, 1)
        },
    ],
    'PercentageComplete': ...,
    'StartedAt': datetime(2015, 1, 1),
    'CompletedAt': datetime(2015, 1, 1)
}


Response Structure

(dict) --

ApplicationId (string) --
The ID of the application that was deployed.

EnvironmentId (string) --
The ID of the environment that was deployed.

DeploymentStrategyId (string) --
The ID of the deployment strategy that was deployed.

ConfigurationProfileId (string) --
The ID of the configuration profile that was deployed.

DeploymentNumber (integer) --
The sequence number of the deployment.

ConfigurationName (string) --
The name of the configuration.

ConfigurationLocationUri (string) --
Information about the source location of the configuration.

ConfigurationVersion (string) --
The configuration version that was deployed.

Description (string) --
The description of the deployment.

DeploymentDurationInMinutes (integer) --
Total amount of time the deployment lasted.

GrowthType (string) --
The algorithm used to define how percentage grew over time.

GrowthFactor (float) --
The percentage of targets to receive a deployed configuration during each interval.

FinalBakeTimeInMinutes (integer) --
The amount of time AppConfig monitored for alarms before considering the deployment to be complete and no longer eligible for automatic roll back.

State (string) --
The state of the deployment.

EventLog (list) --
A list containing all events related to a deployment. The most recent events are displayed first.

(dict) --
An object that describes a deployment event.

EventType (string) --
The type of deployment event. Deployment event types include the start, stop, or completion of a deployment; a percentage update; the start or stop of a bake period; the start or completion of a rollback.

TriggeredBy (string) --
The entity that triggered the deployment event. Events can be triggered by a user, AWS AppConfig, an Amazon CloudWatch alarm, or an internal error.

Description (string) --
A description of the deployment event. Descriptions include, but are not limited to, the user account or the CloudWatch alarm ARN that initiated a rollback, the percentage of hosts that received the deployment, or in the case of an internal error, a recommendation to attempt a new deployment.

OccurredAt (datetime) --
The date and time the event occurred.





PercentageComplete (float) --
The percentage of targets for which the deployment is available.

StartedAt (datetime) --
The time the deployment started.

CompletedAt (datetime) --
The time the deployment completed.







Exceptions

AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException
AppConfig.Client.exceptions.BadRequestException


    :return: {
        'ApplicationId': 'string',
        'EnvironmentId': 'string',
        'DeploymentStrategyId': 'string',
        'ConfigurationProfileId': 'string',
        'DeploymentNumber': 123,
        'ConfigurationName': 'string',
        'ConfigurationLocationUri': 'string',
        'ConfigurationVersion': 'string',
        'Description': 'string',
        'DeploymentDurationInMinutes': 123,
        'GrowthType': 'LINEAR'|'EXPONENTIAL',
        'GrowthFactor': ...,
        'FinalBakeTimeInMinutes': 123,
        'State': 'BAKING'|'VALIDATING'|'DEPLOYING'|'COMPLETE'|'ROLLING_BACK'|'ROLLED_BACK',
        'EventLog': [
            {
                'EventType': 'PERCENTAGE_UPDATED'|'ROLLBACK_STARTED'|'ROLLBACK_COMPLETED'|'BAKE_TIME_STARTED'|'DEPLOYMENT_STARTED'|'DEPLOYMENT_COMPLETED',
                'TriggeredBy': 'USER'|'APPCONFIG'|'CLOUDWATCH_ALARM'|'INTERNAL_ERROR',
                'Description': 'string',
                'OccurredAt': datetime(2015, 1, 1)
            },
        ],
        'PercentageComplete': ...,
        'StartedAt': datetime(2015, 1, 1),
        'CompletedAt': datetime(2015, 1, 1)
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.InternalServerException
    AppConfig.Client.exceptions.BadRequestException
    
    """
    pass

def get_deployment_strategy(DeploymentStrategyId=None):
    """
    Retrieve information about a deployment strategy. A deployment strategy defines important criteria for rolling out your configuration to the designated targets. A deployment strategy includes: the overall duration required, a percentage of targets to receive the deployment during each interval, an algorithm that defines how percentage grows, and bake time.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_deployment_strategy(
        DeploymentStrategyId='string'
    )
    
    
    :type DeploymentStrategyId: string
    :param DeploymentStrategyId: [REQUIRED]\nThe ID of the deployment strategy to get.\n

    :rtype: dict
ReturnsResponse Syntax{
    'Id': 'string',
    'Name': 'string',
    'Description': 'string',
    'DeploymentDurationInMinutes': 123,
    'GrowthType': 'LINEAR'|'EXPONENTIAL',
    'GrowthFactor': ...,
    'FinalBakeTimeInMinutes': 123,
    'ReplicateTo': 'NONE'|'SSM_DOCUMENT'
}


Response Structure

(dict) --
Id (string) --The deployment strategy ID.

Name (string) --The name of the deployment strategy.

Description (string) --The description of the deployment strategy.

DeploymentDurationInMinutes (integer) --Total amount of time the deployment lasted.

GrowthType (string) --The algorithm used to define how percentage grew over time.

GrowthFactor (float) --The percentage of targets that received a deployed configuration during each interval.

FinalBakeTimeInMinutes (integer) --The amount of time AppConfig monitored for alarms before considering the deployment to be complete and no longer eligible for automatic roll back.

ReplicateTo (string) --Save the deployment strategy to a Systems Manager (SSM) document.






Exceptions

AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException
AppConfig.Client.exceptions.BadRequestException


    :return: {
        'Id': 'string',
        'Name': 'string',
        'Description': 'string',
        'DeploymentDurationInMinutes': 123,
        'GrowthType': 'LINEAR'|'EXPONENTIAL',
        'GrowthFactor': ...,
        'FinalBakeTimeInMinutes': 123,
        'ReplicateTo': 'NONE'|'SSM_DOCUMENT'
    }
    
    
    """
    pass

def get_environment(ApplicationId=None, EnvironmentId=None):
    """
    Retrieve information about an environment. An environment is a logical deployment group of AppConfig applications, such as applications in a Production environment or in an EU_Region environment. Each configuration deployment targets an environment. You can enable one or more Amazon CloudWatch alarms for an environment. If an alarm is triggered during a deployment, AppConfig roles back the configuration.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_environment(
        ApplicationId='string',
        EnvironmentId='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe ID of the application that includes the environment you want to get.\n

    :type EnvironmentId: string
    :param EnvironmentId: [REQUIRED]\nThe ID of the environment you wnat to get.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ApplicationId': 'string',
    'Id': 'string',
    'Name': 'string',
    'Description': 'string',
    'State': 'READY_FOR_DEPLOYMENT'|'DEPLOYING'|'ROLLING_BACK'|'ROLLED_BACK',
    'Monitors': [
        {
            'AlarmArn': 'string',
            'AlarmRoleArn': 'string'
        },
    ]
}


Response Structure

(dict) --

ApplicationId (string) --
The application ID.

Id (string) --
The environment ID.

Name (string) --
The name of the environment.

Description (string) --
The description of the environment.

State (string) --
The state of the environment. An environment can be in one of the following states: READY_FOR_DEPLOYMENT , DEPLOYING , ROLLING_BACK , or ROLLED_BACK

Monitors (list) --
Amazon CloudWatch alarms monitored during the deployment.

(dict) --
Amazon CloudWatch alarms to monitor during the deployment process.

AlarmArn (string) --
ARN of the Amazon CloudWatch alarm.

AlarmRoleArn (string) --
ARN of an IAM role for AppConfig to monitor AlarmArn .











Exceptions

AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException
AppConfig.Client.exceptions.BadRequestException


    :return: {
        'ApplicationId': 'string',
        'Id': 'string',
        'Name': 'string',
        'Description': 'string',
        'State': 'READY_FOR_DEPLOYMENT'|'DEPLOYING'|'ROLLING_BACK'|'ROLLED_BACK',
        'Monitors': [
            {
                'AlarmArn': 'string',
                'AlarmRoleArn': 'string'
            },
        ]
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.InternalServerException
    AppConfig.Client.exceptions.BadRequestException
    
    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
ReturnsA paginator object.


    """
    pass

def get_waiter(waiter_name=None):
    """
    Returns an object that can wait for some condition.
    
    :type waiter_name: str
    :param waiter_name: The name of the waiter to get. See the waiters\nsection of the service docs for a list of available waiters.

    :rtype: botocore.waiter.Waiter


    """
    pass

def list_applications(MaxResults=None, NextToken=None):
    """
    List all applications in your AWS account.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_applications(
        MaxResults=123,
        NextToken='string'
    )
    
    
    :type MaxResults: integer
    :param MaxResults: The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.

    :type NextToken: string
    :param NextToken: A token to start the list. Use this token to get the next set of results.

    :rtype: dict

ReturnsResponse Syntax
{
    'Items': [
        {
            'Id': 'string',
            'Name': 'string',
            'Description': 'string'
        },
    ],
    'NextToken': 'string'
}


Response Structure

(dict) --

Items (list) --
The elements from this collection.

(dict) --

Id (string) --
The application ID.

Name (string) --
The application name.

Description (string) --
The description of the application.





NextToken (string) --
The token for the next set of items to return. Use this token to get the next set of results.







Exceptions

AppConfig.Client.exceptions.InternalServerException
AppConfig.Client.exceptions.BadRequestException


    :return: {
        'Items': [
            {
                'Id': 'string',
                'Name': 'string',
                'Description': 'string'
            },
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.InternalServerException
    AppConfig.Client.exceptions.BadRequestException
    
    """
    pass

def list_configuration_profiles(ApplicationId=None, MaxResults=None, NextToken=None):
    """
    Lists the configuration profiles for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_configuration_profiles(
        ApplicationId='string',
        MaxResults=123,
        NextToken='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe application ID.\n

    :type MaxResults: integer
    :param MaxResults: The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.

    :type NextToken: string
    :param NextToken: A token to start the list. Use this token to get the next set of results.

    :rtype: dict

ReturnsResponse Syntax
{
    'Items': [
        {
            'ApplicationId': 'string',
            'Id': 'string',
            'Name': 'string',
            'LocationUri': 'string',
            'ValidatorTypes': [
                'JSON_SCHEMA'|'LAMBDA',
            ]
        },
    ],
    'NextToken': 'string'
}


Response Structure

(dict) --

Items (list) --
The elements from this collection.

(dict) --
A summary of a configuration profile.

ApplicationId (string) --
The application ID.

Id (string) --
The ID of the configuration profile.

Name (string) --
The name of the configuration profile.

LocationUri (string) --
The URI location of the configuration.

ValidatorTypes (list) --
The types of validators in the configuration profile.

(string) --






NextToken (string) --
The token for the next set of items to return. Use this token to get the next set of results.







Exceptions

AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException
AppConfig.Client.exceptions.BadRequestException


    :return: {
        'Items': [
            {
                'ApplicationId': 'string',
                'Id': 'string',
                'Name': 'string',
                'LocationUri': 'string',
                'ValidatorTypes': [
                    'JSON_SCHEMA'|'LAMBDA',
                ]
            },
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def list_deployment_strategies(MaxResults=None, NextToken=None):
    """
    List deployment strategies.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_deployment_strategies(
        MaxResults=123,
        NextToken='string'
    )
    
    
    :type MaxResults: integer
    :param MaxResults: The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.

    :type NextToken: string
    :param NextToken: A token to start the list. Use this token to get the next set of results.

    :rtype: dict

ReturnsResponse Syntax
{
    'Items': [
        {
            'Id': 'string',
            'Name': 'string',
            'Description': 'string',
            'DeploymentDurationInMinutes': 123,
            'GrowthType': 'LINEAR'|'EXPONENTIAL',
            'GrowthFactor': ...,
            'FinalBakeTimeInMinutes': 123,
            'ReplicateTo': 'NONE'|'SSM_DOCUMENT'
        },
    ],
    'NextToken': 'string'
}


Response Structure

(dict) --

Items (list) --
The elements from this collection.

(dict) --

Id (string) --
The deployment strategy ID.

Name (string) --
The name of the deployment strategy.

Description (string) --
The description of the deployment strategy.

DeploymentDurationInMinutes (integer) --
Total amount of time the deployment lasted.

GrowthType (string) --
The algorithm used to define how percentage grew over time.

GrowthFactor (float) --
The percentage of targets that received a deployed configuration during each interval.

FinalBakeTimeInMinutes (integer) --
The amount of time AppConfig monitored for alarms before considering the deployment to be complete and no longer eligible for automatic roll back.

ReplicateTo (string) --
Save the deployment strategy to a Systems Manager (SSM) document.





NextToken (string) --
The token for the next set of items to return. Use this token to get the next set of results.







Exceptions

AppConfig.Client.exceptions.InternalServerException
AppConfig.Client.exceptions.BadRequestException


    :return: {
        'Items': [
            {
                'Id': 'string',
                'Name': 'string',
                'Description': 'string',
                'DeploymentDurationInMinutes': 123,
                'GrowthType': 'LINEAR'|'EXPONENTIAL',
                'GrowthFactor': ...,
                'FinalBakeTimeInMinutes': 123,
                'ReplicateTo': 'NONE'|'SSM_DOCUMENT'
            },
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.InternalServerException
    AppConfig.Client.exceptions.BadRequestException
    
    """
    pass

def list_deployments(ApplicationId=None, EnvironmentId=None, MaxResults=None, NextToken=None):
    """
    Lists the deployments for an environment.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_deployments(
        ApplicationId='string',
        EnvironmentId='string',
        MaxResults=123,
        NextToken='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe application ID.\n

    :type EnvironmentId: string
    :param EnvironmentId: [REQUIRED]\nThe environment ID.\n

    :type MaxResults: integer
    :param MaxResults: The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.

    :type NextToken: string
    :param NextToken: A token to start the list. Use this token to get the next set of results.

    :rtype: dict

ReturnsResponse Syntax
{
    'Items': [
        {
            'DeploymentNumber': 123,
            'ConfigurationName': 'string',
            'ConfigurationVersion': 'string',
            'DeploymentDurationInMinutes': 123,
            'GrowthType': 'LINEAR'|'EXPONENTIAL',
            'GrowthFactor': ...,
            'FinalBakeTimeInMinutes': 123,
            'State': 'BAKING'|'VALIDATING'|'DEPLOYING'|'COMPLETE'|'ROLLING_BACK'|'ROLLED_BACK',
            'PercentageComplete': ...,
            'StartedAt': datetime(2015, 1, 1),
            'CompletedAt': datetime(2015, 1, 1)
        },
    ],
    'NextToken': 'string'
}


Response Structure

(dict) --

Items (list) --
The elements from this collection.

(dict) --
Information about the deployment.

DeploymentNumber (integer) --
The sequence number of the deployment.

ConfigurationName (string) --
The name of the configuration.

ConfigurationVersion (string) --
The version of the configuration.

DeploymentDurationInMinutes (integer) --
Total amount of time the deployment lasted.

GrowthType (string) --
The algorithm used to define how percentage grows over time.

GrowthFactor (float) --
The percentage of targets to receive a deployed configuration during each interval.

FinalBakeTimeInMinutes (integer) --
The amount of time AppConfig monitors for alarms before considering the deployment to be complete and no longer eligible for automatic roll back.

State (string) --
The state of the deployment.

PercentageComplete (float) --
The percentage of targets for which the deployment is available.

StartedAt (datetime) --
Time the deployment started.

CompletedAt (datetime) --
Time the deployment completed.





NextToken (string) --
The token for the next set of items to return. Use this token to get the next set of results.







Exceptions

AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException
AppConfig.Client.exceptions.BadRequestException


    :return: {
        'Items': [
            {
                'DeploymentNumber': 123,
                'ConfigurationName': 'string',
                'ConfigurationVersion': 'string',
                'DeploymentDurationInMinutes': 123,
                'GrowthType': 'LINEAR'|'EXPONENTIAL',
                'GrowthFactor': ...,
                'FinalBakeTimeInMinutes': 123,
                'State': 'BAKING'|'VALIDATING'|'DEPLOYING'|'COMPLETE'|'ROLLING_BACK'|'ROLLED_BACK',
                'PercentageComplete': ...,
                'StartedAt': datetime(2015, 1, 1),
                'CompletedAt': datetime(2015, 1, 1)
            },
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.InternalServerException
    AppConfig.Client.exceptions.BadRequestException
    
    """
    pass

def list_environments(ApplicationId=None, MaxResults=None, NextToken=None):
    """
    List the environments for an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_environments(
        ApplicationId='string',
        MaxResults=123,
        NextToken='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe application ID.\n

    :type MaxResults: integer
    :param MaxResults: The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.

    :type NextToken: string
    :param NextToken: A token to start the list. Use this token to get the next set of results.

    :rtype: dict

ReturnsResponse Syntax
{
    'Items': [
        {
            'ApplicationId': 'string',
            'Id': 'string',
            'Name': 'string',
            'Description': 'string',
            'State': 'READY_FOR_DEPLOYMENT'|'DEPLOYING'|'ROLLING_BACK'|'ROLLED_BACK',
            'Monitors': [
                {
                    'AlarmArn': 'string',
                    'AlarmRoleArn': 'string'
                },
            ]
        },
    ],
    'NextToken': 'string'
}


Response Structure

(dict) --

Items (list) --
The elements from this collection.

(dict) --

ApplicationId (string) --
The application ID.

Id (string) --
The environment ID.

Name (string) --
The name of the environment.

Description (string) --
The description of the environment.

State (string) --
The state of the environment. An environment can be in one of the following states: READY_FOR_DEPLOYMENT , DEPLOYING , ROLLING_BACK , or ROLLED_BACK

Monitors (list) --
Amazon CloudWatch alarms monitored during the deployment.

(dict) --
Amazon CloudWatch alarms to monitor during the deployment process.

AlarmArn (string) --
ARN of the Amazon CloudWatch alarm.

AlarmRoleArn (string) --
ARN of an IAM role for AppConfig to monitor AlarmArn .









NextToken (string) --
The token for the next set of items to return. Use this token to get the next set of results.







Exceptions

AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException
AppConfig.Client.exceptions.BadRequestException


    :return: {
        'Items': [
            {
                'ApplicationId': 'string',
                'Id': 'string',
                'Name': 'string',
                'Description': 'string',
                'State': 'READY_FOR_DEPLOYMENT'|'DEPLOYING'|'ROLLING_BACK'|'ROLLED_BACK',
                'Monitors': [
                    {
                        'AlarmArn': 'string',
                        'AlarmRoleArn': 'string'
                    },
                ]
            },
        ],
        'NextToken': 'string'
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.InternalServerException
    AppConfig.Client.exceptions.BadRequestException
    
    """
    pass

def list_tags_for_resource(ResourceArn=None):
    """
    Retrieves the list of key-value tags assigned to the resource.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_tags_for_resource(
        ResourceArn='string'
    )
    
    
    :type ResourceArn: string
    :param ResourceArn: [REQUIRED]\nThe resource ARN.\n

    :rtype: dict
ReturnsResponse Syntax{
    'Tags': {
        'string': 'string'
    }
}


Response Structure

(dict) --
Tags (dict) --Metadata to assign to AppConfig resources. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define.

(string) --
(string) --









Exceptions

AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.BadRequestException
AppConfig.Client.exceptions.InternalServerException


    :return: {
        'Tags': {
            'string': 'string'
        }
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.BadRequestException
    AppConfig.Client.exceptions.InternalServerException
    
    """
    pass

def start_deployment(ApplicationId=None, EnvironmentId=None, DeploymentStrategyId=None, ConfigurationProfileId=None, ConfigurationVersion=None, Description=None, Tags=None):
    """
    Starts a deployment.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.start_deployment(
        ApplicationId='string',
        EnvironmentId='string',
        DeploymentStrategyId='string',
        ConfigurationProfileId='string',
        ConfigurationVersion='string',
        Description='string',
        Tags={
            'string': 'string'
        }
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe application ID.\n

    :type EnvironmentId: string
    :param EnvironmentId: [REQUIRED]\nThe environment ID.\n

    :type DeploymentStrategyId: string
    :param DeploymentStrategyId: [REQUIRED]\nThe deployment strategy ID.\n

    :type ConfigurationProfileId: string
    :param ConfigurationProfileId: [REQUIRED]\nThe configuration profile ID.\n

    :type ConfigurationVersion: string
    :param ConfigurationVersion: [REQUIRED]\nThe configuration version to deploy.\n

    :type Description: string
    :param Description: A description of the deployment.

    :type Tags: dict
    :param Tags: Metadata to assign to the deployment. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define.\n\n(string) --\n(string) --\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ApplicationId': 'string',
    'EnvironmentId': 'string',
    'DeploymentStrategyId': 'string',
    'ConfigurationProfileId': 'string',
    'DeploymentNumber': 123,
    'ConfigurationName': 'string',
    'ConfigurationLocationUri': 'string',
    'ConfigurationVersion': 'string',
    'Description': 'string',
    'DeploymentDurationInMinutes': 123,
    'GrowthType': 'LINEAR'|'EXPONENTIAL',
    'GrowthFactor': ...,
    'FinalBakeTimeInMinutes': 123,
    'State': 'BAKING'|'VALIDATING'|'DEPLOYING'|'COMPLETE'|'ROLLING_BACK'|'ROLLED_BACK',
    'EventLog': [
        {
            'EventType': 'PERCENTAGE_UPDATED'|'ROLLBACK_STARTED'|'ROLLBACK_COMPLETED'|'BAKE_TIME_STARTED'|'DEPLOYMENT_STARTED'|'DEPLOYMENT_COMPLETED',
            'TriggeredBy': 'USER'|'APPCONFIG'|'CLOUDWATCH_ALARM'|'INTERNAL_ERROR',
            'Description': 'string',
            'OccurredAt': datetime(2015, 1, 1)
        },
    ],
    'PercentageComplete': ...,
    'StartedAt': datetime(2015, 1, 1),
    'CompletedAt': datetime(2015, 1, 1)
}


Response Structure

(dict) --

ApplicationId (string) --
The ID of the application that was deployed.

EnvironmentId (string) --
The ID of the environment that was deployed.

DeploymentStrategyId (string) --
The ID of the deployment strategy that was deployed.

ConfigurationProfileId (string) --
The ID of the configuration profile that was deployed.

DeploymentNumber (integer) --
The sequence number of the deployment.

ConfigurationName (string) --
The name of the configuration.

ConfigurationLocationUri (string) --
Information about the source location of the configuration.

ConfigurationVersion (string) --
The configuration version that was deployed.

Description (string) --
The description of the deployment.

DeploymentDurationInMinutes (integer) --
Total amount of time the deployment lasted.

GrowthType (string) --
The algorithm used to define how percentage grew over time.

GrowthFactor (float) --
The percentage of targets to receive a deployed configuration during each interval.

FinalBakeTimeInMinutes (integer) --
The amount of time AppConfig monitored for alarms before considering the deployment to be complete and no longer eligible for automatic roll back.

State (string) --
The state of the deployment.

EventLog (list) --
A list containing all events related to a deployment. The most recent events are displayed first.

(dict) --
An object that describes a deployment event.

EventType (string) --
The type of deployment event. Deployment event types include the start, stop, or completion of a deployment; a percentage update; the start or stop of a bake period; the start or completion of a rollback.

TriggeredBy (string) --
The entity that triggered the deployment event. Events can be triggered by a user, AWS AppConfig, an Amazon CloudWatch alarm, or an internal error.

Description (string) --
A description of the deployment event. Descriptions include, but are not limited to, the user account or the CloudWatch alarm ARN that initiated a rollback, the percentage of hosts that received the deployment, or in the case of an internal error, a recommendation to attempt a new deployment.

OccurredAt (datetime) --
The date and time the event occurred.





PercentageComplete (float) --
The percentage of targets for which the deployment is available.

StartedAt (datetime) --
The time the deployment started.

CompletedAt (datetime) --
The time the deployment completed.







Exceptions

AppConfig.Client.exceptions.BadRequestException
AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.ConflictException
AppConfig.Client.exceptions.InternalServerException


    :return: {
        'ApplicationId': 'string',
        'EnvironmentId': 'string',
        'DeploymentStrategyId': 'string',
        'ConfigurationProfileId': 'string',
        'DeploymentNumber': 123,
        'ConfigurationName': 'string',
        'ConfigurationLocationUri': 'string',
        'ConfigurationVersion': 'string',
        'Description': 'string',
        'DeploymentDurationInMinutes': 123,
        'GrowthType': 'LINEAR'|'EXPONENTIAL',
        'GrowthFactor': ...,
        'FinalBakeTimeInMinutes': 123,
        'State': 'BAKING'|'VALIDATING'|'DEPLOYING'|'COMPLETE'|'ROLLING_BACK'|'ROLLED_BACK',
        'EventLog': [
            {
                'EventType': 'PERCENTAGE_UPDATED'|'ROLLBACK_STARTED'|'ROLLBACK_COMPLETED'|'BAKE_TIME_STARTED'|'DEPLOYMENT_STARTED'|'DEPLOYMENT_COMPLETED',
                'TriggeredBy': 'USER'|'APPCONFIG'|'CLOUDWATCH_ALARM'|'INTERNAL_ERROR',
                'Description': 'string',
                'OccurredAt': datetime(2015, 1, 1)
            },
        ],
        'PercentageComplete': ...,
        'StartedAt': datetime(2015, 1, 1),
        'CompletedAt': datetime(2015, 1, 1)
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.BadRequestException
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.ConflictException
    AppConfig.Client.exceptions.InternalServerException
    
    """
    pass

def stop_deployment(ApplicationId=None, EnvironmentId=None, DeploymentNumber=None):
    """
    Stops a deployment. This API action works only on deployments that have a status of DEPLOYING . This action moves the deployment to a status of ROLLED_BACK .
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.stop_deployment(
        ApplicationId='string',
        EnvironmentId='string',
        DeploymentNumber=123
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe application ID.\n

    :type EnvironmentId: string
    :param EnvironmentId: [REQUIRED]\nThe environment ID.\n

    :type DeploymentNumber: integer
    :param DeploymentNumber: [REQUIRED]\nThe sequence number of the deployment.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ApplicationId': 'string',
    'EnvironmentId': 'string',
    'DeploymentStrategyId': 'string',
    'ConfigurationProfileId': 'string',
    'DeploymentNumber': 123,
    'ConfigurationName': 'string',
    'ConfigurationLocationUri': 'string',
    'ConfigurationVersion': 'string',
    'Description': 'string',
    'DeploymentDurationInMinutes': 123,
    'GrowthType': 'LINEAR'|'EXPONENTIAL',
    'GrowthFactor': ...,
    'FinalBakeTimeInMinutes': 123,
    'State': 'BAKING'|'VALIDATING'|'DEPLOYING'|'COMPLETE'|'ROLLING_BACK'|'ROLLED_BACK',
    'EventLog': [
        {
            'EventType': 'PERCENTAGE_UPDATED'|'ROLLBACK_STARTED'|'ROLLBACK_COMPLETED'|'BAKE_TIME_STARTED'|'DEPLOYMENT_STARTED'|'DEPLOYMENT_COMPLETED',
            'TriggeredBy': 'USER'|'APPCONFIG'|'CLOUDWATCH_ALARM'|'INTERNAL_ERROR',
            'Description': 'string',
            'OccurredAt': datetime(2015, 1, 1)
        },
    ],
    'PercentageComplete': ...,
    'StartedAt': datetime(2015, 1, 1),
    'CompletedAt': datetime(2015, 1, 1)
}


Response Structure

(dict) --

ApplicationId (string) --
The ID of the application that was deployed.

EnvironmentId (string) --
The ID of the environment that was deployed.

DeploymentStrategyId (string) --
The ID of the deployment strategy that was deployed.

ConfigurationProfileId (string) --
The ID of the configuration profile that was deployed.

DeploymentNumber (integer) --
The sequence number of the deployment.

ConfigurationName (string) --
The name of the configuration.

ConfigurationLocationUri (string) --
Information about the source location of the configuration.

ConfigurationVersion (string) --
The configuration version that was deployed.

Description (string) --
The description of the deployment.

DeploymentDurationInMinutes (integer) --
Total amount of time the deployment lasted.

GrowthType (string) --
The algorithm used to define how percentage grew over time.

GrowthFactor (float) --
The percentage of targets to receive a deployed configuration during each interval.

FinalBakeTimeInMinutes (integer) --
The amount of time AppConfig monitored for alarms before considering the deployment to be complete and no longer eligible for automatic roll back.

State (string) --
The state of the deployment.

EventLog (list) --
A list containing all events related to a deployment. The most recent events are displayed first.

(dict) --
An object that describes a deployment event.

EventType (string) --
The type of deployment event. Deployment event types include the start, stop, or completion of a deployment; a percentage update; the start or stop of a bake period; the start or completion of a rollback.

TriggeredBy (string) --
The entity that triggered the deployment event. Events can be triggered by a user, AWS AppConfig, an Amazon CloudWatch alarm, or an internal error.

Description (string) --
A description of the deployment event. Descriptions include, but are not limited to, the user account or the CloudWatch alarm ARN that initiated a rollback, the percentage of hosts that received the deployment, or in the case of an internal error, a recommendation to attempt a new deployment.

OccurredAt (datetime) --
The date and time the event occurred.





PercentageComplete (float) --
The percentage of targets for which the deployment is available.

StartedAt (datetime) --
The time the deployment started.

CompletedAt (datetime) --
The time the deployment completed.







Exceptions

AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException
AppConfig.Client.exceptions.BadRequestException


    :return: {
        'ApplicationId': 'string',
        'EnvironmentId': 'string',
        'DeploymentStrategyId': 'string',
        'ConfigurationProfileId': 'string',
        'DeploymentNumber': 123,
        'ConfigurationName': 'string',
        'ConfigurationLocationUri': 'string',
        'ConfigurationVersion': 'string',
        'Description': 'string',
        'DeploymentDurationInMinutes': 123,
        'GrowthType': 'LINEAR'|'EXPONENTIAL',
        'GrowthFactor': ...,
        'FinalBakeTimeInMinutes': 123,
        'State': 'BAKING'|'VALIDATING'|'DEPLOYING'|'COMPLETE'|'ROLLING_BACK'|'ROLLED_BACK',
        'EventLog': [
            {
                'EventType': 'PERCENTAGE_UPDATED'|'ROLLBACK_STARTED'|'ROLLBACK_COMPLETED'|'BAKE_TIME_STARTED'|'DEPLOYMENT_STARTED'|'DEPLOYMENT_COMPLETED',
                'TriggeredBy': 'USER'|'APPCONFIG'|'CLOUDWATCH_ALARM'|'INTERNAL_ERROR',
                'Description': 'string',
                'OccurredAt': datetime(2015, 1, 1)
            },
        ],
        'PercentageComplete': ...,
        'StartedAt': datetime(2015, 1, 1),
        'CompletedAt': datetime(2015, 1, 1)
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.InternalServerException
    AppConfig.Client.exceptions.BadRequestException
    
    """
    pass

def tag_resource(ResourceArn=None, Tags=None):
    """
    Metadata to assign to an AppConfig resource. Tags help organize and categorize your AppConfig resources. Each tag consists of a key and an optional value, both of which you define. You can specify a maximum of 50 tags for a resource.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.tag_resource(
        ResourceArn='string',
        Tags={
            'string': 'string'
        }
    )
    
    
    :type ResourceArn: string
    :param ResourceArn: [REQUIRED]\nThe ARN of the resource for which to retrieve tags.\n

    :type Tags: dict
    :param Tags: [REQUIRED]\nThe key-value string map. The valid character set is [a-zA-Z+-=._:/]. The tag key can be up to 128 characters and must not start with aws: . The tag value can be up to 256 characters.\n\n(string) --\n(string) --\n\n\n\n

    :returns: 
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.BadRequestException
    AppConfig.Client.exceptions.InternalServerException
    
    """
    pass

def untag_resource(ResourceArn=None, TagKeys=None):
    """
    Deletes a tag key and value from an AppConfig resource.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.untag_resource(
        ResourceArn='string',
        TagKeys=[
            'string',
        ]
    )
    
    
    :type ResourceArn: string
    :param ResourceArn: [REQUIRED]\nThe ARN of the resource for which to remove tags.\n

    :type TagKeys: list
    :param TagKeys: [REQUIRED]\nThe tag keys to delete.\n\n(string) --\n\n

    :returns: 
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.BadRequestException
    AppConfig.Client.exceptions.InternalServerException
    
    """
    pass

def update_application(ApplicationId=None, Name=None, Description=None):
    """
    Updates an application.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_application(
        ApplicationId='string',
        Name='string',
        Description='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe application ID.\n

    :type Name: string
    :param Name: The name of the application.

    :type Description: string
    :param Description: A description of the application.

    :rtype: dict

ReturnsResponse Syntax
{
    'Id': 'string',
    'Name': 'string',
    'Description': 'string'
}


Response Structure

(dict) --

Id (string) --
The application ID.

Name (string) --
The application name.

Description (string) --
The description of the application.







Exceptions

AppConfig.Client.exceptions.BadRequestException
AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException


    :return: {
        'Id': 'string',
        'Name': 'string',
        'Description': 'string'
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.BadRequestException
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.InternalServerException
    
    """
    pass

def update_configuration_profile(ApplicationId=None, ConfigurationProfileId=None, Name=None, Description=None, RetrievalRoleArn=None, Validators=None):
    """
    Updates a configuration profile.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_configuration_profile(
        ApplicationId='string',
        ConfigurationProfileId='string',
        Name='string',
        Description='string',
        RetrievalRoleArn='string',
        Validators=[
            {
                'Type': 'JSON_SCHEMA'|'LAMBDA',
                'Content': 'string'
            },
        ]
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe application ID.\n

    :type ConfigurationProfileId: string
    :param ConfigurationProfileId: [REQUIRED]\nThe ID of the configuration profile.\n

    :type Name: string
    :param Name: The name of the configuration profile.

    :type Description: string
    :param Description: A description of the configuration profile.

    :type RetrievalRoleArn: string
    :param RetrievalRoleArn: The ARN of an IAM role with permission to access the configuration at the specified LocationUri.

    :type Validators: list
    :param Validators: A list of methods for validating the configuration.\n\n(dict) --A validator provides a syntactic or semantic check to ensure the configuration you want to deploy functions as intended. To validate your application configuration data, you provide a schema or a Lambda function that runs against the configuration. The configuration deployment or update can only proceed when the configuration data is valid.\n\nType (string) -- [REQUIRED]AppConfig supports validators of type JSON_SCHEMA and LAMBDA\n\nContent (string) -- [REQUIRED]Either the JSON Schema content or the Amazon Resource Name (ARN) of an AWS Lambda function.\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ApplicationId': 'string',
    'Id': 'string',
    'Name': 'string',
    'Description': 'string',
    'LocationUri': 'string',
    'RetrievalRoleArn': 'string',
    'Validators': [
        {
            'Type': 'JSON_SCHEMA'|'LAMBDA',
            'Content': 'string'
        },
    ]
}


Response Structure

(dict) --

ApplicationId (string) --
The application ID.

Id (string) --
The configuration profile ID.

Name (string) --
The name of the configuration profile.

Description (string) --
The configuration profile description.

LocationUri (string) --
The URI location of the configuration.

RetrievalRoleArn (string) --
The ARN of an IAM role with permission to access the configuration at the specified LocationUri.

Validators (list) --
A list of methods for validating the configuration.

(dict) --
A validator provides a syntactic or semantic check to ensure the configuration you want to deploy functions as intended. To validate your application configuration data, you provide a schema or a Lambda function that runs against the configuration. The configuration deployment or update can only proceed when the configuration data is valid.

Type (string) --
AppConfig supports validators of type JSON_SCHEMA and LAMBDA

Content (string) --
Either the JSON Schema content or the Amazon Resource Name (ARN) of an AWS Lambda function.











Exceptions

AppConfig.Client.exceptions.BadRequestException
AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException


    :return: {
        'ApplicationId': 'string',
        'Id': 'string',
        'Name': 'string',
        'Description': 'string',
        'LocationUri': 'string',
        'RetrievalRoleArn': 'string',
        'Validators': [
            {
                'Type': 'JSON_SCHEMA'|'LAMBDA',
                'Content': 'string'
            },
        ]
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.BadRequestException
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.InternalServerException
    
    """
    pass

def update_deployment_strategy(DeploymentStrategyId=None, Description=None, DeploymentDurationInMinutes=None, FinalBakeTimeInMinutes=None, GrowthFactor=None, GrowthType=None):
    """
    Updates a deployment strategy.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_deployment_strategy(
        DeploymentStrategyId='string',
        Description='string',
        DeploymentDurationInMinutes=123,
        FinalBakeTimeInMinutes=123,
        GrowthFactor=...,
        GrowthType='LINEAR'|'EXPONENTIAL'
    )
    
    
    :type DeploymentStrategyId: string
    :param DeploymentStrategyId: [REQUIRED]\nThe deployment strategy ID.\n

    :type Description: string
    :param Description: A description of the deployment strategy.

    :type DeploymentDurationInMinutes: integer
    :param DeploymentDurationInMinutes: Total amount of time for a deployment to last.

    :type FinalBakeTimeInMinutes: integer
    :param FinalBakeTimeInMinutes: The amount of time AppConfig monitors for alarms before considering the deployment to be complete and no longer eligible for automatic roll back.

    :type GrowthFactor: float
    :param GrowthFactor: The percentage of targets to receive a deployed configuration during each interval.

    :type GrowthType: string
    :param GrowthType: The algorithm used to define how percentage grows over time. AWS AppConfig supports the following growth types:\n\nLinear : For this type, AppConfig processes the deployment by increments of the growth factor evenly distributed over the deployment time. For example, a linear deployment that uses a growth factor of 20 initially makes the configuration available to 20 percent of the targets. After 1/5th of the deployment time has passed, the system updates the percentage to 40 percent. This continues until 100% of the targets are set to receive the deployed configuration.Exponential : For this type, AppConfig processes the deployment exponentially using the following formula: G*(2^N) . In this formula, G is the growth factor specified by the user and N is the number of steps until the configuration is deployed to all targets. For example, if you specify a growth factor of 2, then the system rolls out the configuration as follows:\n2*(2^0)\n2*(2^1)\n2*(2^2)\n\nExpressed numerically, the deployment rolls out as follows: 2% of the targets, 4% of the targets, 8% of the targets, and continues until the configuration has been deployed to all targets.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'Id': 'string',
    'Name': 'string',
    'Description': 'string',
    'DeploymentDurationInMinutes': 123,
    'GrowthType': 'LINEAR'|'EXPONENTIAL',
    'GrowthFactor': ...,
    'FinalBakeTimeInMinutes': 123,
    'ReplicateTo': 'NONE'|'SSM_DOCUMENT'
}


Response Structure

(dict) --

Id (string) --
The deployment strategy ID.

Name (string) --
The name of the deployment strategy.

Description (string) --
The description of the deployment strategy.

DeploymentDurationInMinutes (integer) --
Total amount of time the deployment lasted.

GrowthType (string) --
The algorithm used to define how percentage grew over time.

GrowthFactor (float) --
The percentage of targets that received a deployed configuration during each interval.

FinalBakeTimeInMinutes (integer) --
The amount of time AppConfig monitored for alarms before considering the deployment to be complete and no longer eligible for automatic roll back.

ReplicateTo (string) --
Save the deployment strategy to a Systems Manager (SSM) document.







Exceptions

AppConfig.Client.exceptions.BadRequestException
AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException


    :return: {
        'Id': 'string',
        'Name': 'string',
        'Description': 'string',
        'DeploymentDurationInMinutes': 123,
        'GrowthType': 'LINEAR'|'EXPONENTIAL',
        'GrowthFactor': ...,
        'FinalBakeTimeInMinutes': 123,
        'ReplicateTo': 'NONE'|'SSM_DOCUMENT'
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.BadRequestException
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.InternalServerException
    
    """
    pass

def update_environment(ApplicationId=None, EnvironmentId=None, Name=None, Description=None, Monitors=None):
    """
    Updates an environment.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_environment(
        ApplicationId='string',
        EnvironmentId='string',
        Name='string',
        Description='string',
        Monitors=[
            {
                'AlarmArn': 'string',
                'AlarmRoleArn': 'string'
            },
        ]
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe application ID.\n

    :type EnvironmentId: string
    :param EnvironmentId: [REQUIRED]\nThe environment ID.\n

    :type Name: string
    :param Name: The name of the environment.

    :type Description: string
    :param Description: A description of the environment.

    :type Monitors: list
    :param Monitors: Amazon CloudWatch alarms to monitor during the deployment process.\n\n(dict) --Amazon CloudWatch alarms to monitor during the deployment process.\n\nAlarmArn (string) --ARN of the Amazon CloudWatch alarm.\n\nAlarmRoleArn (string) --ARN of an IAM role for AppConfig to monitor AlarmArn .\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ApplicationId': 'string',
    'Id': 'string',
    'Name': 'string',
    'Description': 'string',
    'State': 'READY_FOR_DEPLOYMENT'|'DEPLOYING'|'ROLLING_BACK'|'ROLLED_BACK',
    'Monitors': [
        {
            'AlarmArn': 'string',
            'AlarmRoleArn': 'string'
        },
    ]
}


Response Structure

(dict) --

ApplicationId (string) --
The application ID.

Id (string) --
The environment ID.

Name (string) --
The name of the environment.

Description (string) --
The description of the environment.

State (string) --
The state of the environment. An environment can be in one of the following states: READY_FOR_DEPLOYMENT , DEPLOYING , ROLLING_BACK , or ROLLED_BACK

Monitors (list) --
Amazon CloudWatch alarms monitored during the deployment.

(dict) --
Amazon CloudWatch alarms to monitor during the deployment process.

AlarmArn (string) --
ARN of the Amazon CloudWatch alarm.

AlarmRoleArn (string) --
ARN of an IAM role for AppConfig to monitor AlarmArn .











Exceptions

AppConfig.Client.exceptions.BadRequestException
AppConfig.Client.exceptions.ResourceNotFoundException
AppConfig.Client.exceptions.InternalServerException


    :return: {
        'ApplicationId': 'string',
        'Id': 'string',
        'Name': 'string',
        'Description': 'string',
        'State': 'READY_FOR_DEPLOYMENT'|'DEPLOYING'|'ROLLING_BACK'|'ROLLED_BACK',
        'Monitors': [
            {
                'AlarmArn': 'string',
                'AlarmRoleArn': 'string'
            },
        ]
    }
    
    
    :returns: 
    AppConfig.Client.exceptions.BadRequestException
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.InternalServerException
    
    """
    pass

def validate_configuration(ApplicationId=None, ConfigurationProfileId=None, ConfigurationVersion=None):
    """
    Uses the validators in a configuration profile to validate a configuration.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.validate_configuration(
        ApplicationId='string',
        ConfigurationProfileId='string',
        ConfigurationVersion='string'
    )
    
    
    :type ApplicationId: string
    :param ApplicationId: [REQUIRED]\nThe application ID.\n

    :type ConfigurationProfileId: string
    :param ConfigurationProfileId: [REQUIRED]\nThe configuration profile ID.\n

    :type ConfigurationVersion: string
    :param ConfigurationVersion: [REQUIRED]\nThe version of the configuration to validate.\n

    :returns: 
    AppConfig.Client.exceptions.BadRequestException
    AppConfig.Client.exceptions.ResourceNotFoundException
    AppConfig.Client.exceptions.InternalServerException
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    """
    pass

def create_server(Certificate=None, EndpointDetails=None, EndpointType=None, HostKey=None, IdentityProviderDetails=None, IdentityProviderType=None, LoggingRole=None, Protocols=None, Tags=None):
    """
    Instantiates an autoscaling virtual server based on the selected file transfer protocol in AWS. When you make updates to your file transfer protocol-enabled server or when you work with users, use the service-generated ServerId property that is assigned to the newly created server.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_server(
        Certificate='string',
        EndpointDetails={
            'AddressAllocationIds': [
                'string',
            ],
            'SubnetIds': [
                'string',
            ],
            'VpcEndpointId': 'string',
            'VpcId': 'string'
        },
        EndpointType='PUBLIC'|'VPC'|'VPC_ENDPOINT',
        HostKey='string',
        IdentityProviderDetails={
            'Url': 'string',
            'InvocationRole': 'string'
        },
        IdentityProviderType='SERVICE_MANAGED'|'API_GATEWAY',
        LoggingRole='string',
        Protocols=[
            'SFTP'|'FTP'|'FTPS',
        ],
        Tags=[
            {
                'Key': 'string',
                'Value': 'string'
            },
        ]
    )
    
    
    :type Certificate: string
    :param Certificate: The Amazon Resource Name (ARN) of the AWS Certificate Manager (ACM) certificate. Required when Protocols is set to FTPS .

    :type EndpointDetails: dict
    :param EndpointDetails: The virtual private cloud (VPC) endpoint settings that are configured for your file transfer protocol-enabled server. When you host your endpoint within your VPC, you can make it accessible only to resources within your VPC, or you can attach Elastic IPs and make it accessible to clients over the internet. Your VPC\'s default security groups are automatically assigned to your endpoint.\n\nAddressAllocationIds (list) --A list of address allocation IDs that are required to attach an Elastic IP address to your file transfer protocol-enabled server\'s endpoint. This is only valid in the UpdateServer API.\n\nNote\nThis property can only be use when EndpointType is set to VPC .\n\n\n(string) --\n\n\nSubnetIds (list) --A list of subnet IDs that are required to host your file transfer protocol-enabled server endpoint in your VPC.\n\n(string) --\n\n\nVpcEndpointId (string) --The ID of the VPC endpoint.\n\nVpcId (string) --The VPC ID of the VPC in which a file transfer protocol-enabled server\'s endpoint will be hosted.\n\n\n

    :type EndpointType: string
    :param EndpointType: The type of VPC endpoint that you want your file transfer protocol-enabled server to connect to. You can choose to connect to the public internet or a virtual private cloud (VPC) endpoint. With a VPC endpoint, you can restrict access to your server and resources only within your VPC.

    :type HostKey: string
    :param HostKey: The RSA private key as generated by the ssh-keygen -N '' -f my-new-server-key command.\n\nWarning\nIf you aren\'t planning to migrate existing users from an existing SFTP-enabled server to a new server, don\'t update the host key. Accidentally changing a server\'s host key can be disruptive.\n\nFor more information, see Changing the Host Key for Your AWS Transfer Family Server in the AWS Transfer Family User Guide .\n

    :type IdentityProviderDetails: dict
    :param IdentityProviderDetails: Required when IdentityProviderType is set to API_GATEWAY . Accepts an array containing all of the information required to call a customer-supplied authentication API, including the API Gateway URL. Not required when IdentityProviderType is set to SERVICE_MANAGED .\n\nUrl (string) --Contains the location of the service endpoint used to authenticate users.\n\nInvocationRole (string) --Provides the type of InvocationRole used to authenticate the user account.\n\n\n

    :type IdentityProviderType: string
    :param IdentityProviderType: Specifies the mode of authentication for a file transfer protocol-enabled server. The default value is SERVICE_MANAGED , which allows you to store and access user credentials within the AWS Transfer Family service. Use the API_GATEWAY value to integrate with an identity provider of your choosing. The API_GATEWAY setting requires you to provide an API Gateway endpoint URL to call for authentication using the IdentityProviderDetails parameter.

    :type LoggingRole: string
    :param LoggingRole: Allows the service to write your users\' activity to your Amazon CloudWatch logs for monitoring and auditing purposes.

    :type Protocols: list
    :param Protocols: Specifies the file transfer protocol or protocols over which your file transfer protocol client can connect to your server\'s endpoint. The available protocols are:\n\nSecure Shell (SSH) File Transfer Protocol (SFTP): File transfer over SSH\nFile Transfer Protocol Secure (FTPS): File transfer with TLS encryption\nFile Transfer Protocol (FTP): Unencrypted file transfer\n\n\n(string) --\n\n

    :type Tags: list
    :param Tags: Key-value pairs that can be used to group and search for file transfer protocol-enabled servers.\n\n(dict) --Creates a key-value pair for a specific resource. Tags are metadata that you can use to search for and group a resource for various purposes. You can apply tags to servers, users, and roles. A tag key can take more than one value. For example, to group servers for accounting purposes, you might create a tag called Group and assign the values Research and Accounting to that group.\n\nKey (string) -- [REQUIRED]The name assigned to the tag that you create.\n\nValue (string) -- [REQUIRED]Contains one or more values that you assigned to the key name you create.\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ServerId': 'string'
}


Response Structure

(dict) --

ServerId (string) --
The service-assigned ID of the file transfer protocol-enabled server that is created.







Exceptions

Transfer.Client.exceptions.AccessDeniedException
Transfer.Client.exceptions.ServiceUnavailableException
Transfer.Client.exceptions.InternalServiceError
Transfer.Client.exceptions.InvalidRequestException
Transfer.Client.exceptions.ResourceExistsException
Transfer.Client.exceptions.ThrottlingException


    :return: {
        'ServerId': 'string'
    }
    
    
    :returns: 
    Transfer.Client.exceptions.AccessDeniedException
    Transfer.Client.exceptions.ServiceUnavailableException
    Transfer.Client.exceptions.InternalServiceError
    Transfer.Client.exceptions.InvalidRequestException
    Transfer.Client.exceptions.ResourceExistsException
    Transfer.Client.exceptions.ThrottlingException
    
    """
    pass

def create_user(HomeDirectory=None, HomeDirectoryType=None, HomeDirectoryMappings=None, Policy=None, Role=None, ServerId=None, SshPublicKeyBody=None, Tags=None, UserName=None):
    """
    Creates a user and associates them with an existing file transfer protocol-enabled server. You can only create and associate users with servers that have the IdentityProviderType set to SERVICE_MANAGED . Using parameters for CreateUser , you can specify the user name, set the home directory, store the user\'s public key, and assign the user\'s AWS Identity and Access Management (IAM) role. You can also optionally add a scope-down policy, and assign metadata with tags that can be used to group and search for users.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_user(
        HomeDirectory='string',
        HomeDirectoryType='PATH'|'LOGICAL',
        HomeDirectoryMappings=[
            {
                'Entry': 'string',
                'Target': 'string'
            },
        ],
        Policy='string',
        Role='string',
        ServerId='string',
        SshPublicKeyBody='string',
        Tags=[
            {
                'Key': 'string',
                'Value': 'string'
            },
        ],
        UserName='string'
    )
    
    
    :type HomeDirectory: string
    :param HomeDirectory: The landing directory (folder) for a user when they log in to the file transfer protocol-enabled server using the client.\nAn example is your-Amazon-S3-bucket-name>/home/username .\n

    :type HomeDirectoryType: string
    :param HomeDirectoryType: The type of landing directory (folder) you want your users\' home directory to be when they log into the file transfer protocol-enabled server. If you set it to PATH , the user will see the absolute Amazon S3 bucket paths as is in their file transfer protocol clients. If you set it LOGICAL , you will need to provide mappings in the HomeDirectoryMappings for how you want to make Amazon S3 paths visible to your users.

    :type HomeDirectoryMappings: list
    :param HomeDirectoryMappings: Logical directory mappings that specify what Amazon S3 paths and keys should be visible to your user and how you want to make them visible. You will need to specify the 'Entry ' and 'Target ' pair, where Entry shows how the path is made visible and Target is the actual Amazon S3 path. If you only specify a target, it will be displayed as is. You will need to also make sure that your AWS IAM Role provides access to paths in Target . The following is an example.\n\n\'[ '/bucket2/documentation', { 'Entry': 'your-personal-report.pdf', 'Target': '/bucket3/customized-reports/${transfer:UserName}.pdf' } ]\'\nIn most cases, you can use this value instead of the scope-down policy to lock your user down to the designated home directory ('chroot'). To do this, you can set Entry to \'/\' and set Target to the HomeDirectory parameter value.\n\nNote\nIf the target of a logical directory entry does not exist in Amazon S3, the entry will be ignored. As a workaround, you can use the Amazon S3 api to create 0 byte objects as place holders for your directory. If using the CLI, use the s3api call instead of s3 so you can use the put-object operation. For example, you use the following: aws s3api put-object --bucket bucketname --key path/to/folder/ . Make sure that the end of the key name ends in a \'/\' for it to be considered a folder.\n\n\n(dict) --Represents an object that contains entries and a targets for HomeDirectoryMappings .\n\nEntry (string) -- [REQUIRED]Represents an entry and a target for HomeDirectoryMappings .\n\nTarget (string) -- [REQUIRED]Represents the map target that is used in a HomeDirectorymapEntry .\n\n\n\n\n

    :type Policy: string
    :param Policy: A scope-down policy for your user so you can use the same IAM role across multiple users. This policy scopes down user access to portions of their Amazon S3 bucket. Variables that you can use inside this policy include ${Transfer:UserName} , ${Transfer:HomeDirectory} , and ${Transfer:HomeBucket} .\n\nNote\nFor scope-down policies, AWS Transfer Family stores the policy as a JSON blob, instead of the Amazon Resource Name (ARN) of the policy. You save the policy as a JSON blob and pass it in the Policy argument.\nFor an example of a scope-down policy, see Creating a Scope-Down Policy .\nFor more information, see AssumeRole in the AWS Security Token Service API Reference .\n\n

    :type Role: string
    :param Role: [REQUIRED]\nThe IAM role that controls your users\' access to your Amazon S3 bucket. The policies attached to this role will determine the level of access you want to provide your users when transferring files into and out of your Amazon S3 bucket or buckets. The IAM role should also contain a trust relationship that allows the file transfer protocol-enabled server to access your resources when servicing your users\' transfer requests.\n

    :type ServerId: string
    :param ServerId: [REQUIRED]\nA system-assigned unique identifier for a file transfer protocol-enabled server instance. This is the specific server that you added your user to.\n

    :type SshPublicKeyBody: string
    :param SshPublicKeyBody: The public portion of the Secure Shell (SSH) key used to authenticate the user to the file transfer protocol-enabled server.

    :type Tags: list
    :param Tags: Key-value pairs that can be used to group and search for users. Tags are metadata attached to users for any purpose.\n\n(dict) --Creates a key-value pair for a specific resource. Tags are metadata that you can use to search for and group a resource for various purposes. You can apply tags to servers, users, and roles. A tag key can take more than one value. For example, to group servers for accounting purposes, you might create a tag called Group and assign the values Research and Accounting to that group.\n\nKey (string) -- [REQUIRED]The name assigned to the tag that you create.\n\nValue (string) -- [REQUIRED]Contains one or more values that you assigned to the key name you create.\n\n\n\n\n

    :type UserName: string
    :param UserName: [REQUIRED]\nA unique string that identifies a user and is associated with a file transfer protocol-enabled server as specified by the ServerId . This user name must be a minimum of 3 and a maximum of 32 characters long. The following are valid characters: a-z, A-Z, 0-9, underscore, and hyphen. The user name can\'t start with a hyphen.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ServerId': 'string',
    'UserName': 'string'
}


Response Structure

(dict) --

ServerId (string) --
The ID of the file transfer protocol-enabled server that the user is attached to.

UserName (string) --
A unique string that identifies a user account associated with a file transfer protocol-enabled server.







Exceptions

Transfer.Client.exceptions.ServiceUnavailableException
Transfer.Client.exceptions.InternalServiceError
Transfer.Client.exceptions.InvalidRequestException
Transfer.Client.exceptions.ResourceExistsException
Transfer.Client.exceptions.ResourceNotFoundException


    :return: {
        'ServerId': 'string',
        'UserName': 'string'
    }
    
    
    :returns: 
    Transfer.Client.exceptions.ServiceUnavailableException
    Transfer.Client.exceptions.InternalServiceError
    Transfer.Client.exceptions.InvalidRequestException
    Transfer.Client.exceptions.ResourceExistsException
    Transfer.Client.exceptions.ResourceNotFoundException
    
    """
    pass

def delete_server(ServerId=None):
    """
    Deletes the file transfer protocol-enabled server that you specify.
    No response returns from this operation.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_server(
        ServerId='string'
    )
    
    
    :type ServerId: string
    :param ServerId: [REQUIRED]\nA unique system-assigned identifier for a file transfer protocol-enabled server instance.\n

    """
    pass

def delete_ssh_public_key(ServerId=None, SshPublicKeyId=None, UserName=None):
    """
    Deletes a user\'s Secure Shell (SSH) public key.
    No response is returned from this operation.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_ssh_public_key(
        ServerId='string',
        SshPublicKeyId='string',
        UserName='string'
    )
    
    
    :type ServerId: string
    :param ServerId: [REQUIRED]\nA system-assigned unique identifier for a file transfer protocol-enabled server instance that has the user assigned to it.\n

    :type SshPublicKeyId: string
    :param SshPublicKeyId: [REQUIRED]\nA unique identifier used to reference your user\'s specific SSH key.\n

    :type UserName: string
    :param UserName: [REQUIRED]\nA unique string that identifies a user whose public key is being deleted.\n

    :returns: 
    Transfer.Client.exceptions.ServiceUnavailableException
    Transfer.Client.exceptions.InternalServiceError
    Transfer.Client.exceptions.InvalidRequestException
    Transfer.Client.exceptions.ResourceNotFoundException
    Transfer.Client.exceptions.ThrottlingException
    
    """
    pass

def delete_user(ServerId=None, UserName=None):
    """
    Deletes the user belonging to a file transfer protocol-enabled server you specify.
    No response returns from this operation.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_user(
        ServerId='string',
        UserName='string'
    )
    
    
    :type ServerId: string
    :param ServerId: [REQUIRED]\nA system-assigned unique identifier for a file transfer protocol-enabled server instance that has the user assigned to it.\n

    :type UserName: string
    :param UserName: [REQUIRED]\nA unique string that identifies a user that is being deleted from a file transfer protocol-enabled server.\n

    :returns: 
    Transfer.Client.exceptions.ServiceUnavailableException
    Transfer.Client.exceptions.InternalServiceError
    Transfer.Client.exceptions.InvalidRequestException
    Transfer.Client.exceptions.ResourceNotFoundException
    
    """
    pass

def describe_server(ServerId=None):
    """
    Describes a file transfer protocol-enabled server that you specify by passing the ServerId parameter.
    The response contains a description of a server\'s properties. When you set EndpointType to VPC, the response will contain the EndpointDetails .
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_server(
        ServerId='string'
    )
    
    
    :type ServerId: string
    :param ServerId: [REQUIRED]\nA system-assigned unique identifier for a file transfer protocol-enabled server.\n

    :rtype: dict
ReturnsResponse Syntax{
    'Server': {
        'Arn': 'string',
        'Certificate': 'string',
        'EndpointDetails': {
            'AddressAllocationIds': [
                'string',
            ],
            'SubnetIds': [
                'string',
            ],
            'VpcEndpointId': 'string',
            'VpcId': 'string'
        },
        'EndpointType': 'PUBLIC'|'VPC'|'VPC_ENDPOINT',
        'HostKeyFingerprint': 'string',
        'IdentityProviderDetails': {
            'Url': 'string',
            'InvocationRole': 'string'
        },
        'IdentityProviderType': 'SERVICE_MANAGED'|'API_GATEWAY',
        'LoggingRole': 'string',
        'Protocols': [
            'SFTP'|'FTP'|'FTPS',
        ],
        'ServerId': 'string',
        'State': 'OFFLINE'|'ONLINE'|'STARTING'|'STOPPING'|'START_FAILED'|'STOP_FAILED',
        'Tags': [
            {
                'Key': 'string',
                'Value': 'string'
            },
        ],
        'UserCount': 123
    }
}


Response Structure

(dict) --
Server (dict) --An array containing the properties of a file transfer protocol-enabled server with the ServerID you specified.

Arn (string) --Specifies the unique Amazon Resource Name (ARN) for a file transfer protocol-enabled server to be described.

Certificate (string) --The Amazon Resource Name (ARN) of the AWS Certificate Manager (ACM) certificate. Required when Protocols is set to FTPS .

EndpointDetails (dict) --The virtual private cloud (VPC) endpoint settings that you configured for your file transfer protocol-enabled server.

AddressAllocationIds (list) --A list of address allocation IDs that are required to attach an Elastic IP address to your file transfer protocol-enabled server\'s endpoint. This is only valid in the UpdateServer API.

Note
This property can only be use when EndpointType is set to VPC .


(string) --


SubnetIds (list) --A list of subnet IDs that are required to host your file transfer protocol-enabled server endpoint in your VPC.

(string) --


VpcEndpointId (string) --The ID of the VPC endpoint.

VpcId (string) --The VPC ID of the VPC in which a file transfer protocol-enabled server\'s endpoint will be hosted.



EndpointType (string) --The type of endpoint that your file transfer protocol-enabled server is connected to. If your server is connected to a VPC endpoint, your server isn\'t accessible over the public internet.

HostKeyFingerprint (string) --Contains the message-digest algorithm (MD5) hash of a file transfer protocol-enabled server\'s host key. This value is equivalent to the output of the ssh-keygen -l -E md5 -f my-new-server-key command.

IdentityProviderDetails (dict) --Specifies information to call a customer-supplied authentication API. This field is not populated when the IdentityProviderType of a file transfer protocol-enabled server is SERVICE_MANAGED .

Url (string) --Contains the location of the service endpoint used to authenticate users.

InvocationRole (string) --Provides the type of InvocationRole used to authenticate the user account.



IdentityProviderType (string) --Defines the mode of authentication method enabled for this service. A value of SERVICE_MANAGED means that you are using this file transfer protocol-enabled server to store and access user credentials within the service. A value of API_GATEWAY indicates that you have integrated an API Gateway endpoint that will be invoked for authenticating your user into the service.

LoggingRole (string) --An AWS Identity and Access Management (IAM) entity that allows a file transfer protocol-enabled server to turn on Amazon CloudWatch logging for Amazon S3 events. When set, user activity can be viewed in your CloudWatch logs.

Protocols (list) --Specifies the file transfer protocol or protocols over which your file transfer protocol client can connect to your server\'s endpoint. The available protocols are:

Secure Shell (SSH) File Transfer Protocol (SFTP): File transfer over SSH
File Transfer Protocol Secure (FTPS): File transfer with TLS encryption
File Transfer Protocol (FTP): Unencrypted file transfer


(string) --


ServerId (string) --Unique system-assigned identifier for a file transfer protocol-enabled server that you instantiate.

State (string) --The condition of a file transfer protocol-enabled server for the server that was described. A value of ONLINE indicates that the server can accept jobs and transfer files. A State value of OFFLINE means that the server cannot perform file transfer operations.
The states of STARTING and STOPPING indicate that the server is in an intermediate state, either not fully able to respond, or not fully offline. The values of START_FAILED or STOP_FAILED can indicate an error condition.

Tags (list) --Contains the key-value pairs that you can use to search for and group file transfer protocol-enabled servers that were assigned to the server that was described.

(dict) --Creates a key-value pair for a specific resource. Tags are metadata that you can use to search for and group a resource for various purposes. You can apply tags to servers, users, and roles. A tag key can take more than one value. For example, to group servers for accounting purposes, you might create a tag called Group and assign the values Research and Accounting to that group.

Key (string) --The name assigned to the tag that you create.

Value (string) --Contains one or more values that you assigned to the key name you create.





UserCount (integer) --The number of users that are assigned to a file transfer protocol-enabled server you specified with the ServerId .








Exceptions

Transfer.Client.exceptions.ServiceUnavailableException
Transfer.Client.exceptions.InternalServiceError
Transfer.Client.exceptions.InvalidRequestException
Transfer.Client.exceptions.ResourceNotFoundException


    :return: {
        'Server': {
            'Arn': 'string',
            'Certificate': 'string',
            'EndpointDetails': {
                'AddressAllocationIds': [
                    'string',
                ],
                'SubnetIds': [
                    'string',
                ],
                'VpcEndpointId': 'string',
                'VpcId': 'string'
            },
            'EndpointType': 'PUBLIC'|'VPC'|'VPC_ENDPOINT',
            'HostKeyFingerprint': 'string',
            'IdentityProviderDetails': {
                'Url': 'string',
                'InvocationRole': 'string'
            },
            'IdentityProviderType': 'SERVICE_MANAGED'|'API_GATEWAY',
            'LoggingRole': 'string',
            'Protocols': [
                'SFTP'|'FTP'|'FTPS',
            ],
            'ServerId': 'string',
            'State': 'OFFLINE'|'ONLINE'|'STARTING'|'STOPPING'|'START_FAILED'|'STOP_FAILED',
            'Tags': [
                {
                    'Key': 'string',
                    'Value': 'string'
                },
            ],
            'UserCount': 123
        }
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def describe_user(ServerId=None, UserName=None):
    """
    Describes the user assigned to the specific file transfer protocol-enabled server, as identified by its ServerId property.
    The response from this call returns the properties of the user associated with the ServerId value that was specified.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_user(
        ServerId='string',
        UserName='string'
    )
    
    
    :type ServerId: string
    :param ServerId: [REQUIRED]\nA system-assigned unique identifier for a file transfer protocol-enabled server that has this user assigned.\n

    :type UserName: string
    :param UserName: [REQUIRED]\nThe name of the user assigned to one or more file transfer protocol-enabled servers. User names are part of the sign-in credentials to use the AWS Transfer Family service and perform file transfer tasks.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ServerId': 'string',
    'User': {
        'Arn': 'string',
        'HomeDirectory': 'string',
        'HomeDirectoryMappings': [
            {
                'Entry': 'string',
                'Target': 'string'
            },
        ],
        'HomeDirectoryType': 'PATH'|'LOGICAL',
        'Policy': 'string',
        'Role': 'string',
        'SshPublicKeys': [
            {
                'DateImported': datetime(2015, 1, 1),
                'SshPublicKeyBody': 'string',
                'SshPublicKeyId': 'string'
            },
        ],
        'Tags': [
            {
                'Key': 'string',
                'Value': 'string'
            },
        ],
        'UserName': 'string'
    }
}


Response Structure

(dict) --

ServerId (string) --
A system-assigned unique identifier for a file transfer protocol-enabled server that has this user assigned.

User (dict) --
An array containing the properties of the user account for the ServerID value that you specified.

Arn (string) --
Contains the unique Amazon Resource Name (ARN) for the user that was requested to be described.

HomeDirectory (string) --
Specifies the landing directory (or folder), which is the location that files are written to or read from in an Amazon S3 bucket for the described user. An example is ``/your s3 bucket name /home/username `` .

HomeDirectoryMappings (list) --
Logical directory mappings that you specified for what Amazon S3 paths and keys should be visible to your user and how you want to make them visible. You will need to specify the "Entry " and "Target " pair, where Entry shows how the path is made visible and Target is the actual Amazon S3 path. If you only specify a target, it will be displayed as is. You will need to also make sure that your AWS IAM Role provides access to paths in Target .
In most cases, you can use this value instead of the scope-down policy to lock your user down to the designated home directory ("chroot"). To do this, you can set Entry to \'/\' and set Target to the HomeDirectory parameter value.

(dict) --
Represents an object that contains entries and a targets for HomeDirectoryMappings .

Entry (string) --
Represents an entry and a target for HomeDirectoryMappings .

Target (string) --
Represents the map target that is used in a HomeDirectorymapEntry .





HomeDirectoryType (string) --
The type of landing directory (folder) you mapped for your users to see when they log into the file transfer protocol-enabled server. If you set it to PATH , the user will see the absolute Amazon S3 bucket paths as is in their file transfer protocol clients. If you set it LOGICAL , you will need to provide mappings in the HomeDirectoryMappings for how you want to make Amazon S3 paths visible to your users.

Policy (string) --
Specifies the name of the policy in use for the described user.

Role (string) --
Specifies the IAM role that controls your users\' access to your Amazon S3 bucket. The policies attached to this role will determine the level of access you want to provide your users when transferring files into and out of your Amazon S3 bucket or buckets. The IAM role should also contain a trust relationship that allows a file transfer protocol-enabled server to access your resources when servicing your users\' transfer requests.

SshPublicKeys (list) --
Contains the public key portion of the Secure Shell (SSH) keys stored for the described user.

(dict) --
Provides information about the public Secure Shell (SSH) key that is associated with a user account for the specific file transfer protocol-enabled server (as identified by ServerId ). The information returned includes the date the key was imported, the public key contents, and the public key ID. A user can store more than one SSH public key associated with their user name on a specific server.

DateImported (datetime) --
The date that the public key was added to the user account.

SshPublicKeyBody (string) --
The content of the SSH public key as specified by the PublicKeyId .

SshPublicKeyId (string) --
The SshPublicKeyId parameter contains the identifier of the public key.





Tags (list) --
Contains the key-value pairs for the user requested. Tag can be used to search for and group users for a variety of purposes.

(dict) --
Creates a key-value pair for a specific resource. Tags are metadata that you can use to search for and group a resource for various purposes. You can apply tags to servers, users, and roles. A tag key can take more than one value. For example, to group servers for accounting purposes, you might create a tag called Group and assign the values Research and Accounting to that group.

Key (string) --
The name assigned to the tag that you create.

Value (string) --
Contains one or more values that you assigned to the key name you create.





UserName (string) --
The name of the user that was requested to be described. User names are used for authentication purposes. This is the string that will be used by your user when they log in to your file transfer protocol-enabled server.









Exceptions

Transfer.Client.exceptions.ServiceUnavailableException
Transfer.Client.exceptions.InternalServiceError
Transfer.Client.exceptions.InvalidRequestException
Transfer.Client.exceptions.ResourceNotFoundException


    :return: {
        'ServerId': 'string',
        'User': {
            'Arn': 'string',
            'HomeDirectory': 'string',
            'HomeDirectoryMappings': [
                {
                    'Entry': 'string',
                    'Target': 'string'
                },
            ],
            'HomeDirectoryType': 'PATH'|'LOGICAL',
            'Policy': 'string',
            'Role': 'string',
            'SshPublicKeys': [
                {
                    'DateImported': datetime(2015, 1, 1),
                    'SshPublicKeyBody': 'string',
                    'SshPublicKeyId': 'string'
                },
            ],
            'Tags': [
                {
                    'Key': 'string',
                    'Value': 'string'
                },
            ],
            'UserName': 'string'
        }
    }
    
    
    :returns: 
    Transfer.Client.exceptions.ServiceUnavailableException
    Transfer.Client.exceptions.InternalServiceError
    Transfer.Client.exceptions.InvalidRequestException
    Transfer.Client.exceptions.ResourceNotFoundException
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to\nClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid\nfor. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By\ndefault, the http method is whatever is used in the method\'s model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
ReturnsA paginator object.


    """
    pass

def get_waiter(waiter_name=None):
    """
    Returns an object that can wait for some condition.
    
    :type waiter_name: str
    :param waiter_name: The name of the waiter to get. See the waiters\nsection of the service docs for a list of available waiters.

    :rtype: botocore.waiter.Waiter


    """
    pass

def import_ssh_public_key(ServerId=None, SshPublicKeyBody=None, UserName=None):
    """
    Adds a Secure Shell (SSH) public key to a user account identified by a UserName value assigned to the specific file transfer protocol-enabled server, identified by ServerId .
    The response returns the UserName value, the ServerId value, and the name of the SshPublicKeyId .
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.import_ssh_public_key(
        ServerId='string',
        SshPublicKeyBody='string',
        UserName='string'
    )
    
    
    :type ServerId: string
    :param ServerId: [REQUIRED]\nA system-assigned unique identifier for a file transfer protocol-enabled server.\n

    :type SshPublicKeyBody: string
    :param SshPublicKeyBody: [REQUIRED]\nThe public key portion of an SSH key pair.\n

    :type UserName: string
    :param UserName: [REQUIRED]\nThe name of the user account that is assigned to one or more file transfer protocol-enabled servers.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ServerId': 'string',
    'SshPublicKeyId': 'string',
    'UserName': 'string'
}


Response Structure

(dict) --
Identifies the user, the file transfer protocol-enabled server they belong to, and the identifier of the SSH public key associated with that user. A user can have more than one key on each server that they are associated with.

ServerId (string) --
A system-assigned unique identifier for a file transfer protocol-enabled server.

SshPublicKeyId (string) --
The name given to a public key by the system that was imported.

UserName (string) --
A user name assigned to the ServerID value that you specified.







Exceptions

Transfer.Client.exceptions.ServiceUnavailableException
Transfer.Client.exceptions.InternalServiceError
Transfer.Client.exceptions.InvalidRequestException
Transfer.Client.exceptions.ResourceExistsException
Transfer.Client.exceptions.ResourceNotFoundException
Transfer.Client.exceptions.ThrottlingException


    :return: {
        'ServerId': 'string',
        'SshPublicKeyId': 'string',
        'UserName': 'string'
    }
    
    
    :returns: 
    Transfer.Client.exceptions.ServiceUnavailableException
    Transfer.Client.exceptions.InternalServiceError
    Transfer.Client.exceptions.InvalidRequestException
    Transfer.Client.exceptions.ResourceExistsException
    Transfer.Client.exceptions.ResourceNotFoundException
    Transfer.Client.exceptions.ThrottlingException
    
    """
    pass

def list_servers(MaxResults=None, NextToken=None):
    """
    Lists the file transfer protocol-enabled servers that are associated with your AWS account.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_servers(
        MaxResults=123,
        NextToken='string'
    )
    
    
    :type MaxResults: integer
    :param MaxResults: Specifies the number of file transfer protocol-enabled servers to return as a response to the ListServers query.

    :type NextToken: string
    :param NextToken: When additional results are obtained from the``ListServers`` command, a NextToken parameter is returned in the output. You can then pass the NextToken parameter in a subsequent command to continue listing additional file transfer protocol-enabled servers.

    :rtype: dict

ReturnsResponse Syntax
{
    'NextToken': 'string',
    'Servers': [
        {
            'Arn': 'string',
            'IdentityProviderType': 'SERVICE_MANAGED'|'API_GATEWAY',
            'EndpointType': 'PUBLIC'|'VPC'|'VPC_ENDPOINT',
            'LoggingRole': 'string',
            'ServerId': 'string',
            'State': 'OFFLINE'|'ONLINE'|'STARTING'|'STOPPING'|'START_FAILED'|'STOP_FAILED',
            'UserCount': 123
        },
    ]
}


Response Structure

(dict) --

NextToken (string) --
When you can get additional results from the ListServers operation, a NextToken parameter is returned in the output. In a following command, you can pass in the NextToken parameter to continue listing additional file transfer protocol-enabled servers.

Servers (list) --
An array of file transfer protocol-enabled servers that were listed.

(dict) --
Returns properties of a file transfer protocol-enabled server that was specified.

Arn (string) --
The unique Amazon Resource Name (ARN) for a file transfer protocol-enabled server to be listed.

IdentityProviderType (string) --
The authentication method used to validate a user for a file transfer protocol-enabled server that was specified. This can include Secure Shell (SSH), user name and password combinations, or your own custom authentication method. Valid values include SERVICE_MANAGED or API_GATEWAY .

EndpointType (string) --
The type of VPC endpoint that your file transfer protocol-enabled server is connected to. If your server is connected to a VPC endpoint, your server isn\'t accessible over the public internet.

LoggingRole (string) --
The AWS Identity and Access Management (IAM) entity that allows a file transfer protocol-enabled server to turn on Amazon CloudWatch logging.

ServerId (string) --
The unique system assigned identifier for a file transfer protocol-enabled servers that were listed.

State (string) --
Describes the condition of a file transfer protocol-enabled server for the server that was described. A value of ONLINE indicates that the server can accept jobs and transfer files. A State value of OFFLINE means that the server cannot perform file transfer operations.
The states of STARTING and STOPPING indicate that the server is in an intermediate state, either not fully able to respond, or not fully offline. The values of START_FAILED or STOP_FAILED can indicate an error condition.

UserCount (integer) --
A numeric value that indicates the number of users that are assigned to a file transfer protocol-enabled server you specified with the ServerId .











Exceptions

Transfer.Client.exceptions.ServiceUnavailableException
Transfer.Client.exceptions.InternalServiceError
Transfer.Client.exceptions.InvalidNextTokenException
Transfer.Client.exceptions.InvalidRequestException


    :return: {
        'NextToken': 'string',
        'Servers': [
            {
                'Arn': 'string',
                'IdentityProviderType': 'SERVICE_MANAGED'|'API_GATEWAY',
                'EndpointType': 'PUBLIC'|'VPC'|'VPC_ENDPOINT',
                'LoggingRole': 'string',
                'ServerId': 'string',
                'State': 'OFFLINE'|'ONLINE'|'STARTING'|'STOPPING'|'START_FAILED'|'STOP_FAILED',
                'UserCount': 123
            },
        ]
    }
    
    
    :returns: 
    Transfer.Client.exceptions.ServiceUnavailableException
    Transfer.Client.exceptions.InternalServiceError
    Transfer.Client.exceptions.InvalidNextTokenException
    Transfer.Client.exceptions.InvalidRequestException
    
    """
    pass

def list_tags_for_resource(Arn=None, MaxResults=None, NextToken=None):
    """
    Lists all of the tags associated with the Amazon Resource Number (ARN) you specify. The resource can be a user, server, or role.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_tags_for_resource(
        Arn='string',
        MaxResults=123,
        NextToken='string'
    )
    
    
    :type Arn: string
    :param Arn: [REQUIRED]\nRequests the tags associated with a particular Amazon Resource Name (ARN). An ARN is an identifier for a specific AWS resource, such as a server, user, or role.\n

    :type MaxResults: integer
    :param MaxResults: Specifies the number of tags to return as a response to the ListTagsForResource request.

    :type NextToken: string
    :param NextToken: When you request additional results from the ListTagsForResource operation, a NextToken parameter is returned in the input. You can then pass in a subsequent command to the NextToken parameter to continue listing additional tags.

    :rtype: dict

ReturnsResponse Syntax
{
    'Arn': 'string',
    'NextToken': 'string',
    'Tags': [
        {
            'Key': 'string',
            'Value': 'string'
        },
    ]
}


Response Structure

(dict) --

Arn (string) --
The ARN you specified to list the tags of.

NextToken (string) --
When you can get additional results from the ListTagsForResource call, a NextToken parameter is returned in the output. You can then pass in a subsequent command to the NextToken parameter to continue listing additional tags.

Tags (list) --
Key-value pairs that are assigned to a resource, usually for the purpose of grouping and searching for items. Tags are metadata that you define.

(dict) --
Creates a key-value pair for a specific resource. Tags are metadata that you can use to search for and group a resource for various purposes. You can apply tags to servers, users, and roles. A tag key can take more than one value. For example, to group servers for accounting purposes, you might create a tag called Group and assign the values Research and Accounting to that group.

Key (string) --
The name assigned to the tag that you create.

Value (string) --
Contains one or more values that you assigned to the key name you create.











Exceptions

Transfer.Client.exceptions.ServiceUnavailableException
Transfer.Client.exceptions.InternalServiceError
Transfer.Client.exceptions.InvalidNextTokenException
Transfer.Client.exceptions.InvalidRequestException


    :return: {
        'Arn': 'string',
        'NextToken': 'string',
        'Tags': [
            {
                'Key': 'string',
                'Value': 'string'
            },
        ]
    }
    
    
    :returns: 
    Transfer.Client.exceptions.ServiceUnavailableException
    Transfer.Client.exceptions.InternalServiceError
    Transfer.Client.exceptions.InvalidNextTokenException
    Transfer.Client.exceptions.InvalidRequestException
    
    """
    pass

def list_users(MaxResults=None, NextToken=None, ServerId=None):
    """
    Lists the users for a file transfer protocol-enabled server that you specify by passing the ServerId parameter.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_users(
        MaxResults=123,
        NextToken='string',
        ServerId='string'
    )
    
    
    :type MaxResults: integer
    :param MaxResults: Specifies the number of users to return as a response to the ListUsers request.

    :type NextToken: string
    :param NextToken: When you can get additional results from the ListUsers call, a NextToken parameter is returned in the output. You can then pass in a subsequent command to the NextToken parameter to continue listing additional users.

    :type ServerId: string
    :param ServerId: [REQUIRED]\nA system-assigned unique identifier for a file transfer protocol-enabled server that has users assigned to it.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'NextToken': 'string',
    'ServerId': 'string',
    'Users': [
        {
            'Arn': 'string',
            'HomeDirectory': 'string',
            'HomeDirectoryType': 'PATH'|'LOGICAL',
            'Role': 'string',
            'SshPublicKeyCount': 123,
            'UserName': 'string'
        },
    ]
}


Response Structure

(dict) --

NextToken (string) --
When you can get additional results from the ListUsers call, a NextToken parameter is returned in the output. You can then pass in a subsequent command to the NextToken parameter to continue listing additional users.

ServerId (string) --
A system-assigned unique identifier for a file transfer protocol-enabled server that the users are assigned to.

Users (list) --
Returns the user accounts and their properties for the ServerId value that you specify.

(dict) --
Returns properties of the user that you specify.

Arn (string) --
The unique Amazon Resource Name (ARN) for the user that you want to learn about.

HomeDirectory (string) --
Specifies the location that files are written to or read from an Amazon S3 bucket for the user you specify by their ARN.

HomeDirectoryType (string) --
The type of landing directory (folder) you mapped for your users\' home directory. If you set it to PATH , the user will see the absolute Amazon S3 bucket paths as is in their file transfer protocol clients. If you set it LOGICAL , you will need to provide mappings in the HomeDirectoryMappings for how you want to make Amazon S3 paths visible to your users.

Role (string) --
The role in use by this user. A role is an AWS Identity and Access Management (IAM) entity that, in this case, allows a file transfer protocol-enabled server to act on a user\'s behalf. It allows the server to inherit the trust relationship that enables that user to perform file operations to their Amazon S3 bucket.

SshPublicKeyCount (integer) --
The number of SSH public keys stored for the user you specified.

UserName (string) --
The name of the user whose ARN was specified. User names are used for authentication purposes.











Exceptions

Transfer.Client.exceptions.ServiceUnavailableException
Transfer.Client.exceptions.InternalServiceError
Transfer.Client.exceptions.InvalidNextTokenException
Transfer.Client.exceptions.InvalidRequestException
Transfer.Client.exceptions.ResourceNotFoundException


    :return: {
        'NextToken': 'string',
        'ServerId': 'string',
        'Users': [
            {
                'Arn': 'string',
                'HomeDirectory': 'string',
                'HomeDirectoryType': 'PATH'|'LOGICAL',
                'Role': 'string',
                'SshPublicKeyCount': 123,
                'UserName': 'string'
            },
        ]
    }
    
    
    :returns: 
    Transfer.Client.exceptions.ServiceUnavailableException
    Transfer.Client.exceptions.InternalServiceError
    Transfer.Client.exceptions.InvalidNextTokenException
    Transfer.Client.exceptions.InvalidRequestException
    Transfer.Client.exceptions.ResourceNotFoundException
    
    """
    pass

def start_server(ServerId=None):
    """
    Changes the state of a file transfer protocol-enabled server from OFFLINE to ONLINE . It has no impact on a server that is already ONLINE . An ONLINE server can accept and process file transfer jobs.
    The state of STARTING indicates that the server is in an intermediate state, either not fully able to respond, or not fully online. The values of START_FAILED can indicate an error condition.
    No response is returned from this call.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.start_server(
        ServerId='string'
    )
    
    
    :type ServerId: string
    :param ServerId: [REQUIRED]\nA system-assigned unique identifier for a file transfer protocol-enabled server that you start.\n

    """
    pass

def stop_server(ServerId=None):
    """
    Changes the state of a file transfer protocol-enabled server from ONLINE to OFFLINE . An OFFLINE server cannot accept and process file transfer jobs. Information tied to your server, such as server and user properties, are not affected by stopping your server. Stopping the server will not reduce or impact your file transfer protocol endpoint billing.
    The state of STOPPING indicates that the server is in an intermediate state, either not fully able to respond, or not fully offline. The values of STOP_FAILED can indicate an error condition.
    No response is returned from this call.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.stop_server(
        ServerId='string'
    )
    
    
    :type ServerId: string
    :param ServerId: [REQUIRED]\nA system-assigned unique identifier for a file transfer protocol-enabled server that you stopped.\n

    """
    pass

def tag_resource(Arn=None, Tags=None):
    """
    Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN). Resources are users, servers, roles, and other entities.
    There is no response returned from this call.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.tag_resource(
        Arn='string',
        Tags=[
            {
                'Key': 'string',
                'Value': 'string'
            },
        ]
    )
    
    
    :type Arn: string
    :param Arn: [REQUIRED]\nAn Amazon Resource Name (ARN) for a specific AWS resource, such as a server, user, or role.\n

    :type Tags: list
    :param Tags: [REQUIRED]\nKey-value pairs assigned to ARNs that you can use to group and search for resources by type. You can attach this metadata to user accounts for any purpose.\n\n(dict) --Creates a key-value pair for a specific resource. Tags are metadata that you can use to search for and group a resource for various purposes. You can apply tags to servers, users, and roles. A tag key can take more than one value. For example, to group servers for accounting purposes, you might create a tag called Group and assign the values Research and Accounting to that group.\n\nKey (string) -- [REQUIRED]The name assigned to the tag that you create.\n\nValue (string) -- [REQUIRED]Contains one or more values that you assigned to the key name you create.\n\n\n\n\n

    :returns: 
    Transfer.Client.exceptions.ServiceUnavailableException
    Transfer.Client.exceptions.InternalServiceError
    Transfer.Client.exceptions.InvalidRequestException
    Transfer.Client.exceptions.ResourceNotFoundException
    
    """
    pass

def test_identity_provider(ServerId=None, UserName=None, UserPassword=None, ServerProtocol=None):
    """
    If the IdentityProviderType of a file transfer protocol-enabled server is API_Gateway , tests whether your API Gateway is set up successfully. We highly recommend that you call this operation to test your authentication method as soon as you create your server. By doing so, you can troubleshoot issues with the API Gateway integration to ensure that your users can successfully use the service.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.test_identity_provider(
        ServerId='string',
        UserName='string',
        UserPassword='string',
        ServerProtocol='SFTP'|'FTP'|'FTPS'
    )
    
    
    :type ServerId: string
    :param ServerId: [REQUIRED]\nA system-assigned identifier for a specific file transfer protocol-enabled server. That server\'s user authentication method is tested with a user name and password.\n

    :type UserName: string
    :param UserName: [REQUIRED]\nThe name of the user account to be tested.\n

    :type UserPassword: string
    :param UserPassword: The password of the user account to be tested.

    :type ServerProtocol: string
    :param ServerProtocol: The type of file transfer protocol to be tested.\nThe available protocols are:\n\nSecure Shell (SSH) File Transfer Protocol (SFTP)\nFile Transfer Protocol Secure (FTPS)\nFile Transfer Protocol (FTP)\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'Response': 'string',
    'StatusCode': 123,
    'Message': 'string',
    'Url': 'string'
}


Response Structure

(dict) --

Response (string) --
The response that is returned from your API Gateway.

StatusCode (integer) --
The HTTP status code that is the response from your API Gateway.

Message (string) --
A message that indicates whether the test was successful or not.

Url (string) --
The endpoint of the service used to authenticate a user.







Exceptions

Transfer.Client.exceptions.ServiceUnavailableException
Transfer.Client.exceptions.InternalServiceError
Transfer.Client.exceptions.InvalidRequestException
Transfer.Client.exceptions.ResourceNotFoundException


    :return: {
        'Response': 'string',
        'StatusCode': 123,
        'Message': 'string',
        'Url': 'string'
    }
    
    
    :returns: 
    Transfer.Client.exceptions.ServiceUnavailableException
    Transfer.Client.exceptions.InternalServiceError
    Transfer.Client.exceptions.InvalidRequestException
    Transfer.Client.exceptions.ResourceNotFoundException
    
    """
    pass

def untag_resource(Arn=None, TagKeys=None):
    """
    Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN). Resources are users, servers, roles, and other entities.
    No response is returned from this call.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.untag_resource(
        Arn='string',
        TagKeys=[
            'string',
        ]
    )
    
    
    :type Arn: string
    :param Arn: [REQUIRED]\nThe value of the resource that will have the tag removed. An Amazon Resource Name (ARN) is an identifier for a specific AWS resource, such as a server, user, or role.\n

    :type TagKeys: list
    :param TagKeys: [REQUIRED]\nTagKeys are key-value pairs assigned to ARNs that can be used to group and search for resources by type. This metadata can be attached to resources for any purpose.\n\n(string) --\n\n

    :returns: 
    Transfer.Client.exceptions.ServiceUnavailableException
    Transfer.Client.exceptions.InternalServiceError
    Transfer.Client.exceptions.InvalidRequestException
    Transfer.Client.exceptions.ResourceNotFoundException
    
    """
    pass

def update_server(Certificate=None, EndpointDetails=None, EndpointType=None, HostKey=None, IdentityProviderDetails=None, LoggingRole=None, Protocols=None, ServerId=None):
    """
    Updates the file transfer protocol-enabled server\'s properties after that server has been created.
    The UpdateServer call returns the ServerId of the server you updated.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_server(
        Certificate='string',
        EndpointDetails={
            'AddressAllocationIds': [
                'string',
            ],
            'SubnetIds': [
                'string',
            ],
            'VpcEndpointId': 'string',
            'VpcId': 'string'
        },
        EndpointType='PUBLIC'|'VPC'|'VPC_ENDPOINT',
        HostKey='string',
        IdentityProviderDetails={
            'Url': 'string',
            'InvocationRole': 'string'
        },
        LoggingRole='string',
        Protocols=[
            'SFTP'|'FTP'|'FTPS',
        ],
        ServerId='string'
    )
    
    
    :type Certificate: string
    :param Certificate: The Amazon Resource Name (ARN) of the AWS Certificate Manager (ACM) certificate. Required when Protocols is set to FTPS .

    :type EndpointDetails: dict
    :param EndpointDetails: The virtual private cloud (VPC) endpoint settings that are configured for your file transfer protocol-enabled server. With a VPC endpoint, you can restrict access to your server to resources only within your VPC. To control incoming internet traffic, you will need to associate one or more Elastic IP addresses with your server\'s endpoint.\n\nAddressAllocationIds (list) --A list of address allocation IDs that are required to attach an Elastic IP address to your file transfer protocol-enabled server\'s endpoint. This is only valid in the UpdateServer API.\n\nNote\nThis property can only be use when EndpointType is set to VPC .\n\n\n(string) --\n\n\nSubnetIds (list) --A list of subnet IDs that are required to host your file transfer protocol-enabled server endpoint in your VPC.\n\n(string) --\n\n\nVpcEndpointId (string) --The ID of the VPC endpoint.\n\nVpcId (string) --The VPC ID of the VPC in which a file transfer protocol-enabled server\'s endpoint will be hosted.\n\n\n

    :type EndpointType: string
    :param EndpointType: The type of endpoint that you want your file transfer protocol-enabled server to connect to. You can choose to connect to the public internet or a VPC endpoint. With a VPC endpoint, your server isn\'t accessible over the public internet.

    :type HostKey: string
    :param HostKey: The RSA private key as generated by ssh-keygen -N '' -f my-new-server-key .\n\nWarning\nIf you aren\'t planning to migrate existing users from an existing file transfer protocol-enabled server to a new server, don\'t update the host key. Accidentally changing a server\'s host key can be disruptive.\n\nFor more information, see Changing the Host Key for Your AWS Transfer Family Server in the AWS Transfer Family User Guide .\n

    :type IdentityProviderDetails: dict
    :param IdentityProviderDetails: An array containing all of the information required to call a customer\'s authentication API method.\n\nUrl (string) --Contains the location of the service endpoint used to authenticate users.\n\nInvocationRole (string) --Provides the type of InvocationRole used to authenticate the user account.\n\n\n

    :type LoggingRole: string
    :param LoggingRole: Changes the AWS Identity and Access Management (IAM) role that allows Amazon S3 events to be logged in Amazon CloudWatch, turning logging on or off.

    :type Protocols: list
    :param Protocols: Specifies the file transfer protocol or protocols over which your file transfer protocol client can connect to your server\'s endpoint. The available protocols are:\n\nSecure Shell (SSH) File Transfer Protocol (SFTP): File transfer over SSH\nFile Transfer Protocol Secure (FTPS): File transfer with TLS encryption\nFile Transfer Protocol (FTP): Unencrypted file transfer\n\n\n(string) --\n\n

    :type ServerId: string
    :param ServerId: [REQUIRED]\nA system-assigned unique identifier for a file transfer protocol-enabled server instance that the user account is assigned to.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ServerId': 'string'
}


Response Structure

(dict) --

ServerId (string) --
A system-assigned unique identifier for a file transfer protocol-enabled server that the user account is assigned to.







Exceptions

Transfer.Client.exceptions.AccessDeniedException
Transfer.Client.exceptions.ServiceUnavailableException
Transfer.Client.exceptions.ConflictException
Transfer.Client.exceptions.InternalServiceError
Transfer.Client.exceptions.InvalidRequestException
Transfer.Client.exceptions.ResourceExistsException
Transfer.Client.exceptions.ResourceNotFoundException
Transfer.Client.exceptions.ThrottlingException


    :return: {
        'ServerId': 'string'
    }
    
    
    :returns: 
    Transfer.Client.exceptions.AccessDeniedException
    Transfer.Client.exceptions.ServiceUnavailableException
    Transfer.Client.exceptions.ConflictException
    Transfer.Client.exceptions.InternalServiceError
    Transfer.Client.exceptions.InvalidRequestException
    Transfer.Client.exceptions.ResourceExistsException
    Transfer.Client.exceptions.ResourceNotFoundException
    Transfer.Client.exceptions.ThrottlingException
    
    """
    pass

def update_user(HomeDirectory=None, HomeDirectoryType=None, HomeDirectoryMappings=None, Policy=None, Role=None, ServerId=None, UserName=None):
    """
    Assigns new properties to a user. Parameters you pass modify any or all of the following: the home directory, role, and policy for the UserName and ServerId you specify.
    The response returns the ServerId and the UserName for the updated user.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_user(
        HomeDirectory='string',
        HomeDirectoryType='PATH'|'LOGICAL',
        HomeDirectoryMappings=[
            {
                'Entry': 'string',
                'Target': 'string'
            },
        ],
        Policy='string',
        Role='string',
        ServerId='string',
        UserName='string'
    )
    
    
    :type HomeDirectory: string
    :param HomeDirectory: Specifies the landing directory (folder) for a user when they log in to the file transfer protocol-enabled server using their file transfer protocol client.\nAn example is your-Amazon-S3-bucket-name>/home/username .\n

    :type HomeDirectoryType: string
    :param HomeDirectoryType: The type of landing directory (folder) you want your users\' home directory to be when they log into the file transfer protocol-enabled server. If you set it to PATH , the user will see the absolute Amazon S3 bucket paths as is in their file transfer protocol clients. If you set it LOGICAL , you will need to provide mappings in the HomeDirectoryMappings for how you want to make Amazon S3 paths visible to your users.

    :type HomeDirectoryMappings: list
    :param HomeDirectoryMappings: Logical directory mappings that specify what Amazon S3 paths and keys should be visible to your user and how you want to make them visible. You will need to specify the 'Entry ' and 'Target ' pair, where Entry shows how the path is made visible and Target is the actual Amazon S3 path. If you only specify a target, it will be displayed as is. You will need to also make sure that your AWS IAM Role provides access to paths in Target . The following is an example.\n\n\'[ '/bucket2/documentation', { 'Entry': 'your-personal-report.pdf', 'Target': '/bucket3/customized-reports/${transfer:UserName}.pdf' } ]\'\nIn most cases, you can use this value instead of the scope-down policy to lock your user down to the designated home directory ('chroot'). To do this, you can set Entry to \'/\' and set Target to the HomeDirectory parameter value.\n\nNote\nIf the target of a logical directory entry does not exist in Amazon S3, the entry will be ignored. As a workaround, you can use the Amazon S3 api to create 0 byte objects as place holders for your directory. If using the CLI, use the s3api call instead of s3 so you can use the put-object operation. For example, you use the following: aws s3api put-object --bucket bucketname --key path/to/folder/ . Make sure that the end of the key name ends in a / for it to be considered a folder.\n\n\n(dict) --Represents an object that contains entries and a targets for HomeDirectoryMappings .\n\nEntry (string) -- [REQUIRED]Represents an entry and a target for HomeDirectoryMappings .\n\nTarget (string) -- [REQUIRED]Represents the map target that is used in a HomeDirectorymapEntry .\n\n\n\n\n

    :type Policy: string
    :param Policy: Allows you to supply a scope-down policy for your user so you can use the same AWS Identity and Access Management (IAM) role across multiple users. The policy scopes down user access to portions of your Amazon S3 bucket. Variables you can use inside this policy include ${Transfer:UserName} , ${Transfer:HomeDirectory} , and ${Transfer:HomeBucket} .\n\nNote\nFor scope-down policies, AWS Transfer Family stores the policy as a JSON blob, instead of the Amazon Resource Name (ARN) of the policy. You save the policy as a JSON blob and pass it in the Policy argument.\nFor an example of a scope-down policy, see Creating a Scope-Down Policy .\nFor more information, see AssumeRole in the AWS Security Token Service API Reference .\n\n

    :type Role: string
    :param Role: The IAM role that controls your users\' access to your Amazon S3 bucket. The policies attached to this role will determine the level of access you want to provide your users when transferring files into and out of your Amazon S3 bucket or buckets. The IAM role should also contain a trust relationship that allows the file transfer protocol-enabled server to access your resources when servicing your users\' transfer requests.

    :type ServerId: string
    :param ServerId: [REQUIRED]\nA system-assigned unique identifier for a file transfer protocol-enabled server instance that the user account is assigned to.\n

    :type UserName: string
    :param UserName: [REQUIRED]\nA unique string that identifies a user and is associated with a file transfer protocol-enabled server as specified by the ServerId . This is the string that will be used by your user when they log in to your server. This user name is a minimum of 3 and a maximum of 32 characters long. The following are valid characters: a-z, A-Z, 0-9, underscore, and hyphen. The user name can\'t start with a hyphen.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'ServerId': 'string',
    'UserName': 'string'
}


Response Structure

(dict) --

UpdateUserResponse returns the user name and file transfer protocol-enabled server identifier for the request to update a user\'s properties.


ServerId (string) --
A system-assigned unique identifier for a file transfer protocol-enabled server instance that the user account is assigned to.

UserName (string) --
The unique identifier for a user that is assigned to a file transfer protocol-enabled server instance that was specified in the request.







Exceptions

Transfer.Client.exceptions.ServiceUnavailableException
Transfer.Client.exceptions.InternalServiceError
Transfer.Client.exceptions.InvalidRequestException
Transfer.Client.exceptions.ResourceNotFoundException
Transfer.Client.exceptions.ThrottlingException


    :return: {
        'ServerId': 'string',
        'UserName': 'string'
    }
    
    
    :returns: 
    Transfer.Client.exceptions.ServiceUnavailableException
    Transfer.Client.exceptions.InternalServiceError
    Transfer.Client.exceptions.InvalidRequestException
    Transfer.Client.exceptions.ResourceNotFoundException
    Transfer.Client.exceptions.ThrottlingException
    
    """
    pass

